"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTextTableCellFormat(QTextCharFormat):
    """
    https://doc.qt.io/qt-6/qtexttablecellformat.html

    **Detailed Description**

    The table cell format of a table cell in a document specifies the visual
    properties of the table cell.

    The padding properties of a table cell are controlled by **setLeftPadding**
    (), **setRightPadding** (), **setTopPadding** (), and **setBottomPadding**
    (). All the paddings can be set at once using **setPadding** ().

    **See also** **QTextFormat** , **QTextBlockFormat** , **QTextTableFormat** ,
    and **QTextCharFormat** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#QTextTableCellFormat

        **QTextTableCellFormat::QTextTableCellFormat()**

        Constructs a new table cell format object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextTableCellFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#QTextTableCellFormat

        **QTextTableCellFormat::QTextTableCellFormat()**

        Constructs a new table cell format object.
        """
        ...

    def setBorderBrush(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setBorderBrush

        **[since 5.14] void QTextTableCellFormat::setBorderBrush(const QBrush &
        brush )**

        Sets the left, right, top, and bottom border **brush** of the table
        cell.

        This function was introduced in Qt 5.14.

        **See also** **setLeftBorderBrush** (), **setRightBorderBrush** (),
        **setTopBorderBrush** (), **setBottomBorderBrush** (), and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def rightBorderBrush(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#rightBorderBrush

        **[since 5.14] QBrush QTextTableCellFormat::rightBorderBrush() const**

        Returns the right border brush of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setRightBorderBrush** ().
        """
        ...

    def setRightBorderBrush(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setRightBorderBrush

        **[since 5.14] void QTextTableCellFormat::setRightBorderBrush(const
        QBrush & brush )**

        Sets the right border **brush** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **rightBorderBrush** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def leftBorderBrush(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#leftBorderBrush

        **[since 5.14] QBrush QTextTableCellFormat::leftBorderBrush() const**

        Returns the left border brush of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setLeftBorderBrush** ().
        """
        ...

    def setLeftBorderBrush(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setLeftBorderBrush

        **[since 5.14] void QTextTableCellFormat::setLeftBorderBrush(const
        QBrush & brush )**

        Sets the left border **brush** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **leftBorderBrush** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def bottomBorderBrush(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#bottomBorderBrush

        **[since 5.14] QBrush QTextTableCellFormat::bottomBorderBrush() const**

        Returns the bottom border brush of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setBottomBorderBrush** ().
        """
        ...

    def setBottomBorderBrush(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setBottomBorderBrush

        **[since 5.14] void QTextTableCellFormat::setBottomBorderBrush(const
        QBrush & brush )**

        Sets the bottom border **brush** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **bottomBorderBrush** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def topBorderBrush(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#topBorderBrush

        **[since 5.14] QBrush QTextTableCellFormat::topBorderBrush() const**

        Returns the top border brush of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setTopBorderBrush** ().
        """
        ...

    def setTopBorderBrush(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setTopBorderBrush

        **[since 5.14] void QTextTableCellFormat::setTopBorderBrush(const QBrush
        & brush )**

        Sets the top border **brush** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **topBorderBrush** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def setBorderStyle(self, style: QTextFrameFormat.BorderStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setBorderStyle

        **[since 5.14] void
        QTextTableCellFormat::setBorderStyle(QTextFrameFormat::BorderStyle style
        )**

        Sets the left, right, top, and bottom border **style** of the table
        cell.

        This function was introduced in Qt 5.14.

        **See also** **setLeftBorderStyle** (), **setRightBorderStyle** (),
        **setTopBorderStyle** (), **setBottomBorderStyle** (), and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def rightBorderStyle(self) -> QTextFrameFormat.BorderStyle:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#rightBorderStyle

        **[since 5.14] QTextFrameFormat::BorderStyle
        QTextTableCellFormat::rightBorderStyle() const**

        Returns the right border style of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setRightBorderStyle** ().
        """
        ...

    def setRightBorderStyle(self, style: QTextFrameFormat.BorderStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setRightBorderStyle

        **[since 5.14] void
        QTextTableCellFormat::setRightBorderStyle(QTextFrameFormat::BorderStyle
        style )**

        Sets the right border **style** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **rightBorderStyle** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def leftBorderStyle(self) -> QTextFrameFormat.BorderStyle:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#leftBorderStyle

        **[since 5.14] QTextFrameFormat::BorderStyle
        QTextTableCellFormat::leftBorderStyle() const**

        Returns the left border style of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setLeftBorderStyle** ().
        """
        ...

    def setLeftBorderStyle(self, style: QTextFrameFormat.BorderStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setLeftBorderStyle

        **[since 5.14] void
        QTextTableCellFormat::setLeftBorderStyle(QTextFrameFormat::BorderStyle
        style )**

        Sets the left border **style** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **leftBorderStyle** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def bottomBorderStyle(self) -> QTextFrameFormat.BorderStyle:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#bottomBorderStyle

        **[since 5.14] QTextFrameFormat::BorderStyle
        QTextTableCellFormat::bottomBorderStyle() const**

        Returns the bottom border style of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setBottomBorderStyle** ().
        """
        ...

    def setBottomBorderStyle(self, style: QTextFrameFormat.BorderStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setBottomBorderStyle

        **[since 5.14] void
        QTextTableCellFormat::setBottomBorderStyle(QTextFrameFormat::BorderStyle
        style )**

        Sets the bottom border **style** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **bottomBorderStyle** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def topBorderStyle(self) -> QTextFrameFormat.BorderStyle:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#topBorderStyle

        **[since 5.14] QTextFrameFormat::BorderStyle
        QTextTableCellFormat::topBorderStyle() const**

        Returns the top border style of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setTopBorderStyle** ().
        """
        ...

    def setTopBorderStyle(self, style: QTextFrameFormat.BorderStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setTopBorderStyle

        **[since 5.14] void
        QTextTableCellFormat::setTopBorderStyle(QTextFrameFormat::BorderStyle
        style )**

        Sets the top border **style** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **topBorderStyle** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def setBorder(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setBorder

        **[since 5.14] void QTextTableCellFormat::setBorder(qreal width )**

        Sets the left, right, top, and bottom border **width** of the table
        cell.

        This function was introduced in Qt 5.14.

        **See also** **setLeftBorder** (), **setRightBorder** (),
        **setTopBorder** (), **setBottomBorder** (), and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def rightBorder(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#rightBorder

        **[since 5.14] qreal QTextTableCellFormat::rightBorder() const**

        Returns the right border width of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setRightBorder** ().
        """
        ...

    def setRightBorder(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setRightBorder

        **[since 5.14] void QTextTableCellFormat::setRightBorder(qreal width )**

        Sets the right border **width** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **rightBorder** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def leftBorder(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#leftBorder

        **[since 5.14] qreal QTextTableCellFormat::leftBorder() const**

        Returns the left border width of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setLeftBorder** ().
        """
        ...

    def setLeftBorder(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setLeftBorder

        **[since 5.14] void QTextTableCellFormat::setLeftBorder(qreal width )**

        Sets the left border **width** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **leftBorder** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def bottomBorder(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#bottomBorder

        **[since 5.14] qreal QTextTableCellFormat::bottomBorder() const**

        Returns the bottom border width of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setBottomBorder** ().
        """
        ...

    def setBottomBorder(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setBottomBorder

        **[since 5.14] void QTextTableCellFormat::setBottomBorder(qreal width
        )**

        Sets the bottom border **width** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **bottomBorder** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def topBorder(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#topBorder

        **[since 5.14] qreal QTextTableCellFormat::topBorder() const**

        Returns the top border width of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **setTopBorder** ().
        """
        ...

    def setTopBorder(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setTopBorder

        **[since 5.14] void QTextTableCellFormat::setTopBorder(qreal width )**

        Sets the top border **width** of the table cell.

        This function was introduced in Qt 5.14.

        **See also** **topBorder** () and
        **QTextTableFormat::setBorderCollapse** .
        """
        ...

    def setPadding(self, padding: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setPadding

        **void QTextTableCellFormat::setPadding(qreal padding )**

        Sets the left, right, top, and bottom **padding** of the table cell.

        **See also** **setLeftPadding** (), **setRightPadding** (),
        **setTopPadding** (), and **setBottomPadding** ().
        """
        ...

    def rightPadding(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#rightPadding

        **qreal QTextTableCellFormat::rightPadding() const**

        Gets the right padding of the table cell.

        **See also** **setRightPadding** (), **leftPadding** (), **topPadding**
        (), and **bottomPadding** ().
        """
        ...

    def setRightPadding(self, padding: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setRightPadding

        **void QTextTableCellFormat::setRightPadding(qreal padding )**

        Sets the right **padding** of the table cell.

        **See also** **rightPadding** (), **setLeftPadding** (),
        **setTopPadding** (), and **setBottomPadding** ().
        """
        ...

    def leftPadding(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#leftPadding

        **qreal QTextTableCellFormat::leftPadding() const**

        Gets the left padding of the table cell.

        **See also** **setLeftPadding** (), **rightPadding** (), **topPadding**
        (), and **bottomPadding** ().
        """
        ...

    def setLeftPadding(self, padding: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setLeftPadding

        **void QTextTableCellFormat::setLeftPadding(qreal padding )**

        Sets the left **padding** of the table cell.

        **See also** **leftPadding** (), **setRightPadding** (),
        **setTopPadding** (), and **setBottomPadding** ().
        """
        ...

    def bottomPadding(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#bottomPadding

        **qreal QTextTableCellFormat::bottomPadding() const**

        Gets the bottom padding of the table cell.

        **See also** **setBottomPadding** (), **leftPadding** (),
        **rightPadding** (), and **topPadding** ().
        """
        ...

    def setBottomPadding(self, padding: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setBottomPadding

        **void QTextTableCellFormat::setBottomPadding(qreal padding )**

        Sets the bottom **padding** of the table cell.

        **See also** **bottomPadding** (), **setLeftPadding** (),
        **setRightPadding** (), and **setTopPadding** ().
        """
        ...

    def topPadding(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#topPadding

        **qreal QTextTableCellFormat::topPadding() const**

        Gets the top padding of the table cell.

        **See also** **setTopPadding** (), **leftPadding** (), **rightPadding**
        (), and **bottomPadding** ().
        """
        ...

    def setTopPadding(self, padding: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#setTopPadding

        **void QTextTableCellFormat::setTopPadding(qreal padding )**

        Sets the top **padding** of the table cell.

        **See also** **topPadding** (), **setLeftPadding** (),
        **setRightPadding** (), and **setBottomPadding** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtexttablecellformat.html#isValid

        **bool QTextTableCellFormat::isValid() const**

        Returns `true` if this table cell format is valid; otherwise returns
        `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QAbstractButton(QWidget):
    """
    https://doc.qt.io/qt-6/qabstractbutton.html

    **Detailed Description**

    This class implements an **abstract** button. Subclasses of this class
    handle user actions, and specify how the button is drawn.

    QAbstractButton provides support for both push buttons and checkable
    (toggle) buttons. Checkable buttons are implemented in the **QRadioButton**
    and **QCheckBox**  classes. Push buttons are implemented in the
    **QPushButton**  and **QToolButton**  classes; these also provide toggle
    behavior if required.

    Any button can display a label containing text and an icon. **setText** ()
    sets the text; **setIcon** () sets the icon. If a button is disabled, its
    label is changed to give the button a "disabled" appearance.

    If the button is a text button with a string containing an ampersand ('&'),
    QAbstractButton automatically creates a shortcut key. For example:

    **QPushButton**  *button = new **QPushButton** (tr("Ro&ck && Roll"), this);

    The **Alt+C** shortcut is assigned to the button, i.e., when the user
    presses **Alt+C** the button will call **animateClick** (). See the
    **QShortcut**  documentation for details. To display an actual ampersand,
    use '&&'.

    You can also set a custom shortcut key using the **setShortcut** ()
    function. This is useful mostly for buttons that do not have any text, and
    therefore can't have any automatic shortcut.

    button->setIcon(**QIcon** (":/images/print.png"));
    button->setShortcut(tr("Alt+F7"));

    All the buttons provided by Qt (**QPushButton** , **QToolButton** ,
    **QCheckBox** , and **QRadioButton** ) can display both **text**  and
    **icons** .

    A button can be made the default button in a dialog by means of
    **QPushButton::setDefault** () and **QPushButton::setAutoDefault** ().

    QAbstractButton provides most of the states used for buttons:

    * **isDown** () indicates whether the button is **pressed** down.
      *
    **isChecked** () indicates whether the button is **checked**. Only checkable
    buttons can be checked and unchecked (see below).
      * **isEnabled** ()
    indicates whether the button can be pressed by the user.

    **Note:** As
    opposed to other widgets, buttons derived from QAbstractButton accept mouse
    and context menu events when disabled.

      * **setAutoRepeat** () sets
    whether the button will auto-repeat if the user holds it down.
    **autoRepeatDelay**  and **autoRepeatInterval**  define how auto-repetition
    is done.
      * **setCheckable** () sets whether the button is a toggle button
    or not.

    The difference between **isDown** () and **isChecked** () is as follows.
    When the user clicks a toggle button to check it, the button is first
    **pressed** then released into the **checked** state. When the user clicks
    it again (to uncheck it), the button moves first to the **pressed** state,
    then to the **unchecked** state (**isChecked** () and **isDown** () are both
    false).

    QAbstractButton provides four signals:

    1. **pressed** () is emitted when the left mouse button is pressed while the
    mouse cursor is inside the button.
      2. **released** () is emitted when the
    left mouse button is released.
      3. **clicked** () is emitted when the
    button is first pressed and then released, when the shortcut key is typed,
    or when **click** () or **animateClick** () is called.
      4. **toggled** ()
    is emitted when the state of a toggle button changes.

    To subclass QAbstractButton, you must reimplement at least **paintEvent** ()
    to draw the button's outline and its text or pixmap. It is generally
    advisable to reimplement **sizeHint** () as well, and sometimes
    **hitButton** () (to determine whether a button press is within the button).
    For buttons with more than two states (like tri-state buttons), you will
    also have to reimplement **checkStateSet** () and **nextCheckState** ().

    **See also** **QButtonGroup** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#QAbstractButton

        **QAbstractButton::QAbstractButton(QWidget * parent = nullptr)**

        Constructs an abstract button with a **parent**.
        """
        ...

    def timerEvent(self, e: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#timerEvent

        **[override virtual protected] void
        QAbstractButton::timerEvent(QTimerEvent * e )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#changeEvent

        **[override virtual protected] void QAbstractButton::changeEvent(QEvent
        * e )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def focusOutEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#focusOutEvent

        **[override virtual protected] void
        QAbstractButton::focusOutEvent(QFocusEvent * e )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#focusInEvent

        **[override virtual protected] void
        QAbstractButton::focusInEvent(QFocusEvent * e )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def mouseMoveEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#mouseMoveEvent

        **[override virtual protected] void
        QAbstractButton::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#mouseReleaseEvent

        **[override virtual protected] void
        QAbstractButton::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#mousePressEvent

        **[override virtual protected] void
        QAbstractButton::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def keyReleaseEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#keyReleaseEvent

        **[override virtual protected] void
        QAbstractButton::keyReleaseEvent(QKeyEvent * e )**

        Reimplements: **QWidget::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#keyPressEvent

        **[override virtual protected] void
        QAbstractButton::keyPressEvent(QKeyEvent * e )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#event

        **[override virtual protected] bool QAbstractButton::event(QEvent * e
        )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def nextCheckState(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#nextCheckState

        **[virtual protected] void QAbstractButton::nextCheckState()**

        This virtual handler is called when a button is clicked. The default
        implementation calls **setChecked** (!**isChecked** ()) if the button
        **isCheckable** (). It allows subclasses to implement intermediate
        button states.

        **See also** **checkStateSet** ().
        """
        ...

    def checkStateSet(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#checkStateSet

        **[virtual protected] void QAbstractButton::checkStateSet()**

        This virtual handler is called when **setChecked** () is used, unless it
        is called from within **nextCheckState** (). It allows subclasses to
        reset their intermediate button states.

        **See also** **nextCheckState** ().
        """
        ...

    def hitButton(self, pos: QtCore.QPoint) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#hitButton

        **[virtual protected] bool QAbstractButton::hitButton(const QPoint & pos
        ) const**

        Returns `true` if **pos** is inside the clickable button rectangle;
        otherwise returns `false`.

        By default, the clickable area is the entire widget. Subclasses may
        reimplement this function to provide support for clickable areas of
        different shapes and sizes.
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#paintEvent

        **[override pure virtual protected] void
        QAbstractButton::paintEvent(QPaintEvent * e )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def setChecked(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#checked-prop

        **checked : bool**

        This property holds whether the button is checked

        Only checkable buttons can be checked. By default, the button is
        unchecked.

        **Access functions:**

        bool **isChecked** () const
        void **setChecked** (bool)

        **Notifier signal:**

        void ****toggled** ** (bool **checked** )

        **See also** **checkable** .
        """
        ...

    def toggle(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#toggle

        **[slot] void QAbstractButton::toggle()**

        Toggles the state of a checkable button.

        **See also** **checked** .
        """
        ...

    def click(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#click

        **[slot] void QAbstractButton::click()**

        Performs a click.

        All the usual signals associated with a click are emitted as
        appropriate. If the button is checkable, the state of the button is
        toggled.

        This function does nothing if the button is **disabled.**

        **See also** **animateClick** ().
        """
        ...

    def animateClick(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#animateClick

        **[slot] void QAbstractButton::animateClick()**

        Performs an animated click: the button is pressed immediately, and
        released 100ms later.

        Calling this function again before the button is released resets the
        release timer.

        All signals associated with a click are emitted as appropriate.

        This function does nothing if the button is **disabled.**

        **See also** **click** ().
        """
        ...

    def setIconSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#iconSize-prop

        **iconSize : QSize**

        This property holds the icon size used for this button.

        The default size is defined by the GUI style. This is a maximum size for
        the icons. Smaller icons will not be scaled up.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )
        """
        ...

    def group(self) -> "QButtonGroup":
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#group

        **QButtonGroup *QAbstractButton::group() const**

        Returns the group that this button belongs to.

        If the button is not a member of any **QButtonGroup** , this function
        returns `nullptr`.

        **See also** **QButtonGroup** .
        """
        ...

    def autoExclusive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#autoExclusive-prop

        **autoExclusive : bool**

        This property holds whether auto-exclusivity is enabled

        If auto-exclusivity is enabled, checkable buttons that belong to the
        same parent widget behave as if they were part of the same exclusive
        button group. In an exclusive button group, only one button can be
        checked at any time; checking another button automatically unchecks the
        previously checked one.

        The property has no effect on buttons that belong to a button group.

        autoExclusive is off by default, except for radio buttons.

        **Access functions:**

        bool **autoExclusive** () const
        void **setAutoExclusive** (bool)

        **See also** **QRadioButton** .
        """
        ...

    def setAutoExclusive(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#autoExclusive-prop

        **autoExclusive : bool**

        This property holds whether auto-exclusivity is enabled

        If auto-exclusivity is enabled, checkable buttons that belong to the
        same parent widget behave as if they were part of the same exclusive
        button group. In an exclusive button group, only one button can be
        checked at any time; checking another button automatically unchecks the
        previously checked one.

        The property has no effect on buttons that belong to a button group.

        autoExclusive is off by default, except for radio buttons.

        **Access functions:**

        bool **autoExclusive** () const
        void **setAutoExclusive** (bool)

        **See also** **QRadioButton** .
        """
        ...

    def autoRepeat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#autoRepeat-prop

        **autoRepeat : bool**

        This property holds whether autoRepeat is enabled

        If autoRepeat is enabled, then the **pressed** (), **released** (), and
        **clicked** () signals are emitted at regular intervals when the button
        is down. autoRepeat is off by default. The initial delay and the
        repetition interval are defined in milliseconds by **autoRepeatDelay**
        and **autoRepeatInterval** .

        Note: If a button is pressed down by a shortcut key, then auto-repeat is
        enabled and timed by the system and not by this class. The **pressed**
        (), **released** (), and **clicked** () signals will be emitted like in
        the normal case.

        **Access functions:**

        bool **autoRepeat** () const
        void **setAutoRepeat** (bool)
        """
        ...

    def setAutoRepeat(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#autoRepeat-prop

        **autoRepeat : bool**

        This property holds whether autoRepeat is enabled

        If autoRepeat is enabled, then the **pressed** (), **released** (), and
        **clicked** () signals are emitted at regular intervals when the button
        is down. autoRepeat is off by default. The initial delay and the
        repetition interval are defined in milliseconds by **autoRepeatDelay**
        and **autoRepeatInterval** .

        Note: If a button is pressed down by a shortcut key, then auto-repeat is
        enabled and timed by the system and not by this class. The **pressed**
        (), **released** (), and **clicked** () signals will be emitted like in
        the normal case.

        **Access functions:**

        bool **autoRepeat** () const
        void **setAutoRepeat** (bool)
        """
        ...

    def isDown(self) -> bool:
        ...

    def setDown(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#down-prop

        **down : bool**

        This property holds whether the button is pressed down

        If this property is `true`, the button is pressed down. The signals
        **pressed** () and **clicked** () are not emitted if you set this
        property to true. The default is false.

        **Access functions:**

        bool **isDown** () const
        void **setDown** (bool)
        """
        ...

    def isChecked(self) -> bool:
        ...

    def isCheckable(self) -> bool:
        ...

    def setCheckable(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#checkable-prop

        **checkable : bool**

        This property holds whether the button is checkable

        By default, the button is not checkable.

        **Access functions:**

        bool **isCheckable** () const
        void **setCheckable** (bool)

        **See also** **checked** .
        """
        ...

    def shortcut(self) -> QtGui.QKeySequence:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#shortcut-prop

        **shortcut : QKeySequence**

        This property holds the mnemonic associated with the button

        **Access functions:**

        QKeySequence **shortcut** () const
        void **setShortcut** (const
        QKeySequence & **key** )
        """
        ...

    def setShortcut(
        self,
        key: typing.Union[QtGui.QKeySequence, QtGui.QKeySequence.StandardKey, str, int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#shortcut-prop

        **shortcut : QKeySequence**

        This property holds the mnemonic associated with the button

        **Access functions:**

        QKeySequence **shortcut** () const
        void **setShortcut** (const
        QKeySequence & **key** )
        """
        ...

    def iconSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#iconSize-prop

        **iconSize : QSize**

        This property holds the icon size used for this button.

        The default size is defined by the GUI style. This is a maximum size for
        the icons. Smaller icons will not be scaled up.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **size** )
        """
        ...

    def icon(self) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#icon-prop

        **icon : QIcon**

        This property holds the icon shown on the button

        The icon's default size is defined by the GUI style, but can be adjusted
        by setting the **iconSize**  property.

        **Access functions:**

        QIcon **icon** () const
        void **setIcon** (const QIcon & **icon** )
        """
        ...

    def setIcon(self, icon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#icon-prop

        **icon : QIcon**

        This property holds the icon shown on the button

        The icon's default size is defined by the GUI style, but can be adjusted
        by setting the **iconSize**  property.

        **Access functions:**

        QIcon **icon** () const
        void **setIcon** (const QIcon & **icon** )
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#text-prop

        **text : QString**

        This property holds the text shown on the button

        If the button has no text, the text() function will return an empty
        string.

        If the text contains an ampersand character ('&'), a shortcut is
        automatically created for it. The character that follows the '&' will be
        used as the shortcut key. Any previous shortcut will be overwritten or
        cleared if no shortcut is defined by the text. See the **QShortcut**
        documentation for details. To display an actual ampersand, use '&&'.

        There is no default text.

        **Access functions:**

        QString **text** () const
        void **setText** (const QString & **text** )

        **Member Function Documentation**
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#text-prop

        **text : QString**

        This property holds the text shown on the button

        If the button has no text, the text() function will return an empty
        string.

        If the text contains an ampersand character ('&'), a shortcut is
        automatically created for it. The character that follows the '&' will be
        used as the shortcut key. Any previous shortcut will be overwritten or
        cleared if no shortcut is defined by the text. See the **QShortcut**
        documentation for details. To display an actual ampersand, use '&&'.

        There is no default text.

        **Access functions:**

        QString **text** () const
        void **setText** (const QString & **text** )

        **Member Function Documentation**
        """
        ...

    def autoRepeatInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#autoRepeatInterval-prop

        **autoRepeatInterval : int**

        This property holds the interval of auto-repetition

        If **autoRepeat**  is enabled, then autoRepeatInterval defines the
        length of the auto-repetition interval in millisecons.

        **Access functions:**

        int **autoRepeatInterval** () const
        void **setAutoRepeatInterval**
        (int)

        **See also** **autoRepeat**  and **autoRepeatDelay** .
        """
        ...

    def setAutoRepeatInterval(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#autoRepeatInterval-prop

        **autoRepeatInterval : int**

        This property holds the interval of auto-repetition

        If **autoRepeat**  is enabled, then autoRepeatInterval defines the
        length of the auto-repetition interval in millisecons.

        **Access functions:**

        int **autoRepeatInterval** () const
        void **setAutoRepeatInterval**
        (int)

        **See also** **autoRepeat**  and **autoRepeatDelay** .
        """
        ...

    def autoRepeatDelay(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#autoRepeatDelay-prop

        **autoRepeatDelay : int**

        This property holds the initial delay of auto-repetition

        If **autoRepeat**  is enabled, then autoRepeatDelay defines the initial
        delay in milliseconds before auto-repetition kicks in.

        **Access functions:**

        int **autoRepeatDelay** () const
        void **setAutoRepeatDelay** (int)

        **See also** **autoRepeat**  and **autoRepeatInterval** .
        """
        ...

    def setAutoRepeatDelay(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#autoRepeatDelay-prop

        **autoRepeatDelay : int**

        This property holds the initial delay of auto-repetition

        If **autoRepeat**  is enabled, then autoRepeatDelay defines the initial
        delay in milliseconds before auto-repetition kicks in.

        **Access functions:**

        int **autoRepeatDelay** () const
        void **setAutoRepeatDelay** (int)

        **See also** **autoRepeat**  and **autoRepeatInterval** .
        """
        ...

    @property
    def clicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#clicked

        **[signal] void QAbstractButton::clicked(bool checked = false)**

        This signal is emitted when the button is activated (i.e., pressed down
        then released while the mouse cursor is inside the button), when the
        shortcut key is typed, or when **click** () or **animateClick** () is
        called. Notably, this signal is **not** emitted if you call **setDown**
        (), **setChecked** () or **toggle** ().

        If the button is checkable, **checked** is true if the button is
        checked, or false if the button is unchecked.

        **See also** **pressed** (), **released** (), and **toggled** ().
        """
        ...

    @property
    def pressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#pressed

        **[signal] void QAbstractButton::pressed()**

        This signal is emitted when the button is pressed down.

        **See also** **released** () and **clicked** ().
        """
        ...

    @property
    def released(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#released

        **[signal] void QAbstractButton::released()**

        This signal is emitted when the button is released.

        **See also** **pressed** (), **clicked** (), and **toggled** ().
        """
        ...

    @property
    def toggled(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractbutton.html#toggled

        **[signal] void QAbstractButton::toggled(bool checked )**

        This signal is emitted whenever a checkable button changes its state.
        **checked** is true if the button is checked, or false if the button is
        unchecked.

        This may be the result of a user action, **click** () slot activation,
        or because **setChecked** () is called.

        The states of buttons in exclusive button groups are updated before this
        signal is emitted. This means that slots can act on either the "off"
        signal or the "on" signal emitted by the buttons in the group whose
        states have changed.

        For example, a slot that reacts to signals emitted by newly checked
        buttons but which ignores signals from buttons that have been unchecked
        can be implemented using the following pattern:

        void MyWidget::reactToToggle(bool checked)
            {
               if (checked) {
        // Examine the new button states.
                  ...
               }
            }

        Button groups can be created using the **QButtonGroup**  class, and
        updates to the button states monitored with the
        **QButtonGroup::buttonClicked** () signal.

        **Note:** Notifier signal for property **checked** .

        **See also** **checked**  and **clicked** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QApplication(QtGui.QGuiApplication):
    """
    https://doc.qt.io/qt-6/qapplication.html

    **Detailed Description**

    QApplication specializes **QGuiApplication**  with some functionality needed
    for **QWidget** -based applications. It handles widget specific
    initialization, finalization.

    For any GUI application using Qt, there is precisely **one** QApplication
    object, no matter whether the application has 0, 1, 2 or more windows at any
    given time. For non-**QWidget**  based Qt applications, use
    **QGuiApplication**  instead, as it does not depend on the **QtWidgets**
    library.

    Some GUI applications provide a special batch mode ie. provide command line
    arguments for executing tasks without manual intervention. In such non-GUI
    mode, it is often sufficient to instantiate a plain **QCoreApplication**  to
    avoid unnecessarily initializing resources needed for a graphical user
    interface. The following example shows how to dynamically create an
    appropriate type of application instance:

    **QCoreApplication** * createApplication(int &argc, char *argv[])
        {
    for (int i = 1; i < argc; ++i) {
                if (!qstrcmp(argv[i], "-no-
    gui"))
                    return new **QCoreApplication** (argc, argv);
    }
            return new **QApplication** (argc, argv);
        }

        int
    main(int argc, char* argv[])
        {
            **QScopedPointer**
    <**QCoreApplication** > app(createApplication(argc, argv));

            if
    (qobject_cast<**QApplication**  *>(app.data())) {
               // start GUI
    version...
            } else {
               // start non-GUI version...
            }
    return app->exec();
        }

    The QApplication object is accessible through the **instance** () function
    that returns a pointer equivalent to the global **qApp**  pointer.

    QApplication's main areas of responsibility are:

    * It initializes the application with the user's desktop settings such as
    **palette** (), **font** () and **doubleClickInterval** (). It keeps track
    of these properties in case the user changes the desktop globally, for
    example through some kind of control panel.
      * It performs event handling,
    meaning that it receives events from the underlying window system and
    dispatches them to the relevant widgets. By using **sendEvent** () and
    **postEvent** () you can send your own events to widgets.
      * It parses
    common command line arguments and sets its internal state accordingly. See
    the **constructor documentation**  below for more details.
      * It defines
    the application's look and feel, which is encapsulated in a **QStyle**
    object. This can be changed at runtime with **setStyle** ().
      * It provides
    localization of strings that are visible to the user via **translate** ().
    * It provides some magical objects like the **clipboard** ().
      * It knows
    about the application's windows. You can ask which widget is at a certain
    position using **widgetAt** (), get a list of **topLevelWidgets** () and
    **closeAllWindows** (), etc.
      * It manages the application's mouse cursor
    handling, see **setOverrideCursor** ()

    Since the QApplication object does so much initialization, it **must** be
    created before any other objects related to the user interface are created.
    QApplication also deals with common command line arguments. Hence, it is
    usually a good idea to create it **before** any interpretation or
    modification of `argv` is done in the application itself.

    Groups of functions
    System settings**desktopSettingsAware** (),
    **setDesktopSettingsAware** (), **cursorFlashTime** (),
    **setCursorFlashTime** (), **doubleClickInterval** (),
    **setDoubleClickInterval** (), **setKeyboardInputInterval** (),
    **wheelScrollLines** (), **setWheelScrollLines** (), **palette** (),
    **setPalette** (), **font** (), **setFont** (), fontMetrics().
    Event
    handling**exec** (), **processEvents** (), **exit** (), **quit** ().
    **sendEvent** (), **postEvent** (), **sendPostedEvents** (),
    **removePostedEvents** (), **notify** ().
    GUI Styles**style** (),
    **setStyle** ().
    Text handling**installTranslator** (),
    **removeTranslator** () **translate** ().
    Widgets**allWidgets** (),
    **topLevelWidgets** (), **activePopupWidget** (), **activeModalWidget** (),
    **clipboard** (), **focusWidget** (), **activeWindow** (), **widgetAt** ().
    Advanced cursor handling**overrideCursor** (), **setOverrideCursor** (),
    **restoreOverrideCursor** ().
    Miscellaneous**closeAllWindows** (),
    **startingUp** (), **closingDown** ().

    **See also** **QCoreApplication** , **QAbstractEventDispatcher** ,
    **QEventLoop** , and **QSettings** .
    """

    def __init__(self, argv: typing.List[str]) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#QApplication

        **QApplication::QApplication(int & argc , char ** argv )**

        Initializes the window system and constructs an application object with
        **argc** command line arguments in **argv**.

        **Warning:** The data referred to by **argc** and **argv** must stay
        valid for the entire lifetime of the QApplication object. In addition,
        **argc** must be greater than zero and **argv** must contain at least
        one valid character string.

        The global `qApp` pointer refers to this application object. Only one
        application object should be created.

        This application object must be constructed before any **paint devices**
        (including widgets, pixmaps, bitmaps etc.).

        **Note:** **argc** and **argv** might be changed as Qt removes command
        line arguments that it recognizes.

        All Qt programs automatically support the following command line
        options:

        * -style= **style** , sets the application GUI style. Possible values
        depend on your system configuration. If you compiled Qt with additional
        styles or have additional styles as plugins these will be available to
        the `-style` command line option. You can also set the style for all Qt
        applications by setting the `QT_STYLE_OVERRIDE` environment variable.
        * -style **style** , is the same as listed above.
          * -stylesheet=
        **stylesheet** , sets the application **styleSheet** . The value must be
        a path to a file that contains the Style Sheet.

        **Note:** Relative URLs
        in the Style Sheet file are relative to the Style Sheet file's path.
        * -stylesheet **stylesheet** , is the same as listed above.
          *
        -widgetcount, prints debug message at the end about number of widgets
        left undestroyed and maximum number of widgets existed at the same time
        * -reverse, sets the application's layout direction to
        **Qt::RightToLeft**
          * -qmljsdebugger=, activates the QML/JS debugger
        with a specified port. The value must be of format port:1234[,block],
        where block is optional and will make the application wait until a
        debugger connects to it.

        **See also** **QCoreApplication::arguments** ().
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qapplication.html#event

        **[override virtual protected] bool QApplication::event(QEvent * e )**

        Reimplements: **QGuiApplication::event** (QEvent *e).
        """
        ...

    def setStyleSheet(self, sheet: str) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#styleSheet-prop

        **styleSheet : QString**

        This property holds the application style sheet

        By default, this property returns an empty string unless the user
        specifies the `-stylesheet` option on the command line when running the
        application.

        **Access functions:**

        QString **styleSheet** () const
        void **setStyleSheet** (const QString
        & **sheet** )

        **See also** **QWidget::setStyle** () and **Qt Style Sheets** .
        """
        ...

    def setAutoSipEnabled(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#autoSipEnabled-prop

        **autoSipEnabled : bool**

        toggles automatic SIP (software input panel) visibility

        Set this property to `true` to automatically display the SIP when
        entering widgets that accept keyboard input. This property only affects
        widgets with the WA_InputMethodEnabled attribute set, and is typically
        used to launch a virtual keyboard on devices which have very few or no
        keys.

        **The property only has an effect on platforms that use software input
        panels.**

        The default is platform dependent.

        **Access functions:**

        bool **autoSipEnabled** () const
        void **setAutoSipEnabled** (const
        bool **enabled** )
        """
        ...

    @staticmethod
    def closeAllWindows() -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#closeAllWindows

        **[static slot] void QApplication::closeAllWindows()**

        Closes all top-level windows.

        This function is particularly useful for applications with many top-
        level windows.

        The windows are closed in random order, until one window does not accept
        the close event. The application quits when the last window was
        successfully closed, unless **quitOnLastWindowClosed**  is set to false.
        To trigger application termination from e.g. a menu, use
        **QCoreApplication::quit** () instead of this function.

        **See also** **quitOnLastWindowClosed** , **lastWindowClosed** (),
        **QWidget::close** (), **QWidget::closeEvent** (), **lastWindowClosed**
        (), **QCoreApplication::quit** (), **topLevelWidgets** (), and
        **QWidget::isWindow** ().
        """
        ...

    @staticmethod
    def aboutQt() -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#aboutQt

        **[static slot] void QApplication::aboutQt()**

        Displays a simple message box about Qt. The message includes the version
        number of Qt being used by the application.

        This is useful for inclusion in the **Help** menu of an application, as
        shown in the **Menus**  example.

        This function is a convenience slot for **QMessageBox::aboutQt** ().
        """
        ...

    def styleSheet(self) -> str:
        """
        https://doc.qt.io/qt-6/qapplication.html#styleSheet-prop

        **styleSheet : QString**

        This property holds the application style sheet

        By default, this property returns an empty string unless the user
        specifies the `-stylesheet` option on the command line when running the
        application.

        **Access functions:**

        QString **styleSheet** () const
        void **setStyleSheet** (const QString
        & **sheet** )

        **See also** **QWidget::setStyle** () and **Qt Style Sheets** .
        """
        ...

    def autoSipEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qapplication.html#autoSipEnabled-prop

        **autoSipEnabled : bool**

        toggles automatic SIP (software input panel) visibility

        Set this property to `true` to automatically display the SIP when
        entering widgets that accept keyboard input. This property only affects
        widgets with the WA_InputMethodEnabled attribute set, and is typically
        used to launch a virtual keyboard on devices which have very few or no
        keys.

        **The property only has an effect on platforms that use software input
        panels.**

        The default is platform dependent.

        **Access functions:**

        bool **autoSipEnabled** () const
        void **setAutoSipEnabled** (const
        bool **enabled** )
        """
        ...

    def notify(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qapplication.html#notify

        **[override virtual] bool QApplication::notify(QObject * receiver ,
        QEvent * e )**

        Reimplements: **QGuiApplication::notify** (QObject *object, QEvent
        *event).
        """
        ...

    @staticmethod
    def exec() -> int:
        """
        https://doc.qt.io/qt-6/qapplication.html#exec

        **[static] int QApplication::exec()**

        Enters the main event loop and waits until **exit** () is called, then
        returns the value that was set to **exit** () (which is 0 if **exit** ()
        is called via **quit** ()).

        It is necessary to call this function to start event handling. The main
        event loop receives events from the window system and dispatches these
        to the application widgets.

        Generally, no user interaction can take place before calling exec(). As
        a special case, modal widgets like **QMessageBox**  can be used before
        calling exec(), because modal widgets call exec() to start a local event
        loop.

        To make your application perform idle processing, i.e., executing a
        special function whenever there are no pending events, use a **QTimer**
        with 0 timeout. More advanced idle processing schemes can be achieved
        using **processEvents** ().

        We recommend that you connect clean-up code to the **aboutToQuit** ()
        signal, instead of putting it in your application's `main()` function.
        This is because, on some platforms the QApplication::exec() call may not
        return. For example, on the Windows platform, when the user logs off,
        the system terminates the process after Qt closes all top-level windows.
        Hence, there is **no guarantee** that the application will have time to
        exit its event loop and execute code at the end of the `main()`
        function, after the QApplication::exec() call.

        **See also** **quitOnLastWindowClosed** , **QCoreApplication::quit** (),
        **QCoreApplication::exit** (), **QCoreApplication::processEvents** (),
        and **QCoreApplication::exec** ().
        """
        ...

    @staticmethod
    def setEffectEnabled(a0: QtCore.Qt.UIEffect, enabled: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#setEffectEnabled

        **[static] void QApplication::setEffectEnabled(Qt::UIEffect effect ,
        bool enable = true)**

        Enables the UI effect **effect** if **enable** is true, otherwise the
        effect will not be used.

        **Note:** All effects are disabled on screens running at less than
        16-bit color depth.

        **See also** **isEffectEnabled** (), **Qt::UIEffect** , and
        **setDesktopSettingsAware** ().
        """
        ...

    @staticmethod
    def isEffectEnabled(a0: QtCore.Qt.UIEffect) -> bool:
        """
        https://doc.qt.io/qt-6/qapplication.html#isEffectEnabled

        **[static] bool QApplication::isEffectEnabled(Qt::UIEffect effect )**

        Returns `true` if **effect** is enabled; otherwise returns `false`.

        By default, Qt will try to use the desktop settings. To prevent this,
        call setDesktopSettingsAware(false).

        **Note:** All effects are disabled on screens running at less than
        16-bit color depth.

        **See also** **setEffectEnabled** () and **Qt::UIEffect** .
        """
        ...

    @staticmethod
    def startDragDistance() -> int:
        """
        https://doc.qt.io/qt-6/qapplication.html#startDragDistance-prop

        **startDragDistance : int**

        This property holds the minimum distance required for a drag and drop
        operation to start.

        If you support drag and drop in your application, and want to start a
        drag and drop operation after the user has moved the cursor a certain
        distance with a button held down, you should use this property's value
        as the minimum distance required.

        For example, if the mouse position of the click is stored in `startPos`
        and the current position (e.g. in the mouse move event) is `currentPos`,
        you can find out if a drag should be started with code like this:

        if ((startPos - currentPos).manhattanLength() >=
        **QApplication** ::startDragDistance())
                startTheDrag();

        Qt uses this value internally, e.g. in **QFileDialog** .

        The default value (if the platform doesn't provide a different default)
        is 10 pixels.

        **Access functions:**

        int **startDragDistance** ()
        void **setStartDragDistance** (int **l**
        )

        **See also** **startDragTime** (), **QPoint::manhattanLength** (), and
        **Drag and Drop** .
        """
        ...

    @staticmethod
    def setStartDragDistance(l: int) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#startDragDistance-prop

        **startDragDistance : int**

        This property holds the minimum distance required for a drag and drop
        operation to start.

        If you support drag and drop in your application, and want to start a
        drag and drop operation after the user has moved the cursor a certain
        distance with a button held down, you should use this property's value
        as the minimum distance required.

        For example, if the mouse position of the click is stored in `startPos`
        and the current position (e.g. in the mouse move event) is `currentPos`,
        you can find out if a drag should be started with code like this:

        if ((startPos - currentPos).manhattanLength() >=
        **QApplication** ::startDragDistance())
                startTheDrag();

        Qt uses this value internally, e.g. in **QFileDialog** .

        The default value (if the platform doesn't provide a different default)
        is 10 pixels.

        **Access functions:**

        int **startDragDistance** ()
        void **setStartDragDistance** (int **l**
        )

        **See also** **startDragTime** (), **QPoint::manhattanLength** (), and
        **Drag and Drop** .
        """
        ...

    @staticmethod
    def startDragTime() -> int:
        """
        https://doc.qt.io/qt-6/qapplication.html#startDragTime-prop

        **startDragTime : int**

        This property holds the time in milliseconds that a mouse button must be
        held down before a drag and drop operation will begin

        If you support drag and drop in your application, and want to start a
        drag and drop operation after the user has held down a mouse button for
        a certain amount of time, you should use this property's value as the
        delay.

        Qt also uses this delay internally, e.g. in **QTextEdit**  and
        **QLineEdit** , for starting a drag.

        The default value is 500 ms.

        **Access functions:**

        int **startDragTime** ()
        void **setStartDragTime** (int **ms** )

        **See also** **startDragDistance** () and **Drag and Drop** .
        """
        ...

    @staticmethod
    def setStartDragTime(ms: int) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#startDragTime-prop

        **startDragTime : int**

        This property holds the time in milliseconds that a mouse button must be
        held down before a drag and drop operation will begin

        If you support drag and drop in your application, and want to start a
        drag and drop operation after the user has held down a mouse button for
        a certain amount of time, you should use this property's value as the
        delay.

        Qt also uses this delay internally, e.g. in **QTextEdit**  and
        **QLineEdit** , for starting a drag.

        The default value is 500 ms.

        **Access functions:**

        int **startDragTime** ()
        void **setStartDragTime** (int **ms** )

        **See also** **startDragDistance** () and **Drag and Drop** .
        """
        ...

    @staticmethod
    def wheelScrollLines() -> int:
        """
        https://doc.qt.io/qt-6/qapplication.html#wheelScrollLines-prop

        **wheelScrollLines : int**

        This property holds the number of lines to scroll a widget, when the
        mouse wheel is rotated.

        If the value exceeds the widget's number of visible lines, the widget
        should interpret the scroll operation as a single **page up** or **page
        down**. If the widget is an **item view class** , then the result of
        scrolling one **line** depends on the setting of the widget's **scroll
        mode** . Scroll one **line** can mean **scroll one item**  or **scroll
        one pixel** .

        By default, this property has a value of 3.

        **Access functions:**

        int **wheelScrollLines** ()
        void **setWheelScrollLines** (int)

        **See also** **QStyleHints::wheelScrollLines** ().

        **Member Function Documentation**
        """
        ...

    @staticmethod
    def setWheelScrollLines(a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#wheelScrollLines-prop

        **wheelScrollLines : int**

        This property holds the number of lines to scroll a widget, when the
        mouse wheel is rotated.

        If the value exceeds the widget's number of visible lines, the widget
        should interpret the scroll operation as a single **page up** or **page
        down**. If the widget is an **item view class** , then the result of
        scrolling one **line** depends on the setting of the widget's **scroll
        mode** . Scroll one **line** can mean **scroll one item**  or **scroll
        one pixel** .

        By default, this property has a value of 3.

        **Access functions:**

        int **wheelScrollLines** ()
        void **setWheelScrollLines** (int)

        **See also** **QStyleHints::wheelScrollLines** ().

        **Member Function Documentation**
        """
        ...

    @staticmethod
    def keyboardInputInterval() -> int:
        """
        https://doc.qt.io/qt-6/qapplication.html#keyboardInputInterval-prop

        **keyboardInputInterval : int**

        This property holds the time limit in milliseconds that distinguishes a
        key press from two consecutive key presses

        The default value on X11 is 400 milliseconds. On Windows and Mac OS, the
        operating system's value is used.

        **Access functions:**

        int **keyboardInputInterval** ()
        void **setKeyboardInputInterval**
        (int)
        """
        ...

    @staticmethod
    def setKeyboardInputInterval(a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#keyboardInputInterval-prop

        **keyboardInputInterval : int**

        This property holds the time limit in milliseconds that distinguishes a
        key press from two consecutive key presses

        The default value on X11 is 400 milliseconds. On Windows and Mac OS, the
        operating system's value is used.

        **Access functions:**

        int **keyboardInputInterval** ()
        void **setKeyboardInputInterval**
        (int)
        """
        ...

    @staticmethod
    def doubleClickInterval() -> int:
        """
        https://doc.qt.io/qt-6/qapplication.html#doubleClickInterval-prop

        **doubleClickInterval : int**

        This property holds the time limit in milliseconds that distinguishes a
        double click from two consecutive mouse clicks

        The default value on X11 is 400 milliseconds. On Windows and Mac OS, the
        operating system's value is used.

        **Access functions:**

        int **doubleClickInterval** ()
        void **setDoubleClickInterval** (int)
        """
        ...

    @staticmethod
    def setDoubleClickInterval(a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#doubleClickInterval-prop

        **doubleClickInterval : int**

        This property holds the time limit in milliseconds that distinguishes a
        double click from two consecutive mouse clicks

        The default value on X11 is 400 milliseconds. On Windows and Mac OS, the
        operating system's value is used.

        **Access functions:**

        int **doubleClickInterval** ()
        void **setDoubleClickInterval** (int)
        """
        ...

    @staticmethod
    def cursorFlashTime() -> int:
        """
        https://doc.qt.io/qt-6/qapplication.html#cursorFlashTime-prop

        **cursorFlashTime : int**

        This property holds the text cursor's flash (blink) time in milliseconds

        The flash time is the time required to display, invert and restore the
        caret display. Usually the text cursor is displayed for half the cursor
        flash time, then hidden for the same amount of time, but this may vary.

        The default value on X11 is 1000 milliseconds. On Windows, the **Control
        Panel** value is used and setting this property sets the cursor flash
        time for all applications.

        We recommend that widgets do not cache this value as it may change at
        any time if the user changes the global desktop settings.

        **Note:** This property may hold a negative value, for instance if
        cursor blinking is disabled.

        **Access functions:**

        int **cursorFlashTime** ()
        void **setCursorFlashTime** (int)
        """
        ...

    @staticmethod
    def setCursorFlashTime(a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#cursorFlashTime-prop

        **cursorFlashTime : int**

        This property holds the text cursor's flash (blink) time in milliseconds

        The flash time is the time required to display, invert and restore the
        caret display. Usually the text cursor is displayed for half the cursor
        flash time, then hidden for the same amount of time, but this may vary.

        The default value on X11 is 1000 milliseconds. On Windows, the **Control
        Panel** value is used and setting this property sets the cursor flash
        time for all applications.

        We recommend that widgets do not cache this value as it may change at
        any time if the user changes the global desktop settings.

        **Note:** This property may hold a negative value, for instance if
        cursor blinking is disabled.

        **Access functions:**

        int **cursorFlashTime** ()
        void **setCursorFlashTime** (int)
        """
        ...

    @staticmethod
    def alert(widget: QWidget, msecs: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#alert

        **[static] void QApplication::alert(QWidget * widget , int msec = 0)**

        Causes an alert to be shown for **widget** if the window is not the
        active window. The alert is shown for **msec** milliseconds. If **msec**
        is zero (the default), then the alert is shown indefinitely until the
        window becomes active again.

        Currently this function does nothing on Qt for Embedded Linux.

        On macOS, this works more at the application level and will cause the
        application icon to bounce in the dock.

        On Windows, this causes the window's taskbar entry to flash for a time.
        If **msec** is zero, the flashing will stop and the taskbar entry will
        turn a different color (currently orange).

        On X11, this will cause the window to be marked as "demands attention",
        the window must not be hidden (i.e. not have hide() called on it, but be
        visible in some sort of way) in order for this to work.
        """
        ...

    @staticmethod
    def beep() -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#beep

        **[static] void QApplication::beep()**

        Sounds the bell, using the default volume and sound. The function is
        **not** available in Qt for Embedded Linux.
        """
        ...

    @typing.overload
    @staticmethod
    def topLevelAt(p: QtCore.QPoint) -> QWidget:
        """
        https://doc.qt.io/qt-6/qapplication.html#topLevelAt

        **[static] QWidget *QApplication::topLevelAt(const QPoint & point )**

        Returns the top-level widget at the given **point** ; returns `nullptr`
        if there is no such widget.
        """
        ...

    @typing.overload
    @staticmethod
    def topLevelAt(x: int, y: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qapplication.html#topLevelAt-1

        **[static] QWidget *QApplication::topLevelAt(int x , int y )**

        This is an overloaded function.

        Returns the top-level widget at the point ( **x** , **y** ); returns 0
        if there is no such widget.
        """
        ...

    @typing.overload
    @staticmethod
    def widgetAt(p: QtCore.QPoint) -> QWidget:
        """
        https://doc.qt.io/qt-6/qapplication.html#widgetAt

        **[static] QWidget *QApplication::widgetAt(const QPoint & point )**

        Returns the widget at global screen position **point** , or `nullptr` if
        there is no Qt widget there.

        This function can be slow.

        **See also** **QCursor::pos** (), **QWidget::grabMouse** (), and
        **QWidget::grabKeyboard** ().
        """
        ...

    @typing.overload
    @staticmethod
    def widgetAt(x: int, y: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qapplication.html#widgetAt-1

        **[static] QWidget *QApplication::widgetAt(int x , int y )**

        This is an overloaded function.

        Returns the widget at global screen position ( **x** , **y** ), or
        `nullptr` if there is no Qt widget there.
        """
        ...

    @staticmethod
    def setActiveWindow(act: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#setActiveWindow

        **[static] void QApplication::setActiveWindow(QWidget * active )**

        Sets the active window to the **active** widget in response to a system
        event. The function is called from the platform specific event handlers.

        **Warning:** This function does **not** set the keyboard focus to the
        active widget. Call **QWidget::activateWindow** () instead.

        It sets the **activeWindow** () and **focusWidget** () attributes and
        sends proper **WindowActivate** /**WindowDeactivate**  and **FocusIn**
        /**FocusOut**  events to all appropriate widgets. The window will then
        be painted in active state (e.g. cursors in line edits will blink), and
        it will have tool tips enabled.

        **See also** **activeWindow** () and **QWidget::activateWindow** ().
        """
        ...

    @staticmethod
    def activeWindow() -> QWidget:
        """
        https://doc.qt.io/qt-6/qapplication.html#activeWindow

        **[static] QWidget *QApplication::activeWindow()**

        Returns the application top-level window that has the keyboard input
        focus, or `nullptr` if no application window has the focus. There might
        be an activeWindow() even if there is no **focusWidget** (), for example
        if no widget in that window accepts key events.

        **See also** **setActiveWindow** (), **QWidget::setFocus** (),
        **QWidget::hasFocus** (), and **focusWidget** ().
        """
        ...

    @staticmethod
    def focusWidget() -> QWidget:
        """
        https://doc.qt.io/qt-6/qapplication.html#focusWidget

        **[static] QWidget *QApplication::focusWidget()**

        Returns the application widget that has the keyboard input focus, or
        `nullptr` if no widget in this application has the focus.

        **See also** **QWidget::setFocus** (), **QWidget::hasFocus** (),
        **activeWindow** (), and **focusChanged** ().
        """
        ...

    @staticmethod
    def activeModalWidget() -> QWidget:
        """
        https://doc.qt.io/qt-6/qapplication.html#activeModalWidget

        **[static] QWidget *QApplication::activeModalWidget()**

        Returns the active modal widget.

        A modal widget is a special top-level widget which is a subclass of
        **QDialog**  that specifies the modal parameter of the constructor as
        true. A modal widget must be closed before the user can continue with
        other parts of the program.

        Modal widgets are organized in a stack. This function returns the active
        modal widget at the top of the stack.

        **See also** **activePopupWidget** () and **topLevelWidgets** ().
        """
        ...

    @staticmethod
    def activePopupWidget() -> QWidget:
        """
        https://doc.qt.io/qt-6/qapplication.html#activePopupWidget

        **[static] QWidget *QApplication::activePopupWidget()**

        Returns the active popup widget.

        A popup widget is a special top-level widget that sets the
        `Qt::WType_Popup` widget flag, e.g. the **QMenu**  widget. When the
        application opens a popup widget, all events are sent to the popup.
        Normal widgets and modal widgets cannot be accessed before the popup
        widget is closed.

        Only other popup widgets may be opened when a popup widget is shown. The
        popup widgets are organized in a stack. This function returns the active
        popup widget at the top of the stack.

        **See also** **activeModalWidget** () and **topLevelWidgets** ().
        """
        ...

    @staticmethod
    def topLevelWidgets() -> typing.List[QWidget]:
        """
        https://doc.qt.io/qt-6/qapplication.html#topLevelWidgets

        **[static] QWidgetList QApplication::topLevelWidgets()**

        Returns a list of the top-level widgets (windows) in the application.

        **Note:** Some of the top-level widgets may be hidden, for example a
        tooltip if no tooltip is currently shown.

        Example:

        void showAllHiddenTopLevelWidgets()
            {
                const QWidgetList
        topLevelWidgets = **QApplication** ::topLevelWidgets();
                for
        (**QWidget**  *widget : topLevelWidgets) {
                    if
        (widget->isHidden())
                        widget->show();
                }
            }

        **See also** **allWidgets** (), **QWidget::isWindow** (), and
        **QWidget::isHidden** ().
        """
        ...

    @staticmethod
    def allWidgets() -> typing.List[QWidget]:
        """
        https://doc.qt.io/qt-6/qapplication.html#allWidgets

        **[static] QWidgetList QApplication::allWidgets()**

        Returns a list of all the widgets in the application.

        The list is empty (**QList::isEmpty** ()) if there are no widgets.

        **Note:** Some of the widgets may be hidden.

        Example:

        void updateAllWidgets()
            {
                const QWidgetList allWidgets =
        **QApplication** ::allWidgets();
                for (**QWidget**  *widget :
        allWidgets)
                    widget->update();
            }

        **See also** **topLevelWidgets** () and **QWidget::isVisible** ().
        """
        ...

    @staticmethod
    def setFont(a0: QtGui.QFont, className: typing.Optional[str] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#setFont

        **[static] void QApplication::setFont(const QFont & font , const char *
        className = nullptr)**

        Changes the default application font to **font**. If **className** is
        passed, the change applies only to classes that inherit **className**
        (as reported by **QObject::inherits** ()).

        On application start-up, the default font depends on the window system.
        It can vary depending on both the window system version and the locale.
        This function lets you override the default font; but overriding may be
        a bad idea because, for example, some locales need extra large fonts to
        support their special characters.

        **Warning:** Do not use this function in conjunction with **Qt Style
        Sheets** . The font of an application can be customized using the "font"
        style sheet property. To set a bold font for all QPushButtons, set the
        application **styleSheet** () as "**QPushButton**  { font: bold }"

        **See also** **font** (), **fontMetrics** (), and **QWidget::setFont**
        ().
        """
        ...

    @typing.overload
    @staticmethod
    def font() -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qapplication.html#font

        **[static] QFont QApplication::font()**

        Returns the default application font.

        **See also** **setFont** (), **fontMetrics** (), and **QWidget::font**
        ().
        """
        ...

    @typing.overload
    @staticmethod
    def font(a0: QWidget) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qapplication.html#font-1

        **[static] QFont QApplication::font(const QWidget * widget )**

        This is an overloaded function.

        Returns the default font for the **widget**. If a default font was not
        registered for the **widget** 's class, it returns the default font of
        its nearest registered superclass.

        **See also** **fontMetrics** (), **setFont** (), and
        **QWidget::setFont** ().
        """
        ...

    @typing.overload
    @staticmethod
    def font(className: str) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qapplication.html#font-2

        **[static] QFont QApplication::font(const char * className )**

        This is an overloaded function.

        Returns the font for widgets of the given **className**.

        **See also** **setFont** () and **QWidget::font** ().
        """
        ...

    @staticmethod
    def setPalette(a0: QtGui.QPalette, className: typing.Optional[str] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#setPalette

        **[static] void QApplication::setPalette(const QPalette & palette ,
        const char * className = nullptr)**

        Changes the application palette to **palette**.

        If **className** is passed, the change applies only to widgets that
        inherit **className** (as reported by **QObject::inherits** ()). If
        **className** is left 0, the change affects all widgets, thus overriding
        any previously set class specific palettes.

        The palette may be changed according to the current GUI style in
        **QStyle::polish** ().

        **Warning:** Do not use this function in conjunction with **Qt Style
        Sheets** . When using style sheets, the palette of a widget can be
        customized using the "color", "background-color", "selection-color",
        "selection-background-color" and "alternate-background-color".

        **Note:** Some styles do not use the palette for all drawing, for
        instance, if they make use of native theme engines. This is the case for
        the Windows Vista and macOS styles.

        **See also** **QWidget::setPalette** (), **palette** (), and
        **QStyle::polish** ().
        """
        ...

    @typing.overload
    @staticmethod
    def palette() -> QtGui.QPalette:
        """
        https://doc.qt.io/qt-6/qapplication.html#palette

        **[static] QPalette QApplication::palette(const QWidget * widget )**

        If a **widget** is passed, the default palette for the widget's class is
        returned. This may or may not be the application palette. In most cases
        there is no special palette for certain types of widgets, but one
        notable exception is the popup menu under Windows, if the user has
        defined a special background color for menus in the display settings.

        **See also** **setPalette** () and **QWidget::palette** ().
        """
        ...

    @typing.overload
    @staticmethod
    def palette(a0: QWidget) -> QtGui.QPalette:
        """
        https://doc.qt.io/qt-6/qapplication.html#palette-1

        **[static] QPalette QApplication::palette(const char * className )**

        This is an overloaded function.

        Returns the palette for widgets of the given **className**.

        **See also** **setPalette** () and **QWidget::palette** ().
        """
        ...

    @typing.overload
    @staticmethod
    def palette(className: str) -> QtGui.QPalette:
        """
        https://doc.qt.io/qt-6/qapplication.html#palette

        **[static] QPalette QApplication::palette(const QWidget * widget )**

        If a **widget** is passed, the default palette for the widget's class is
        returned. This may or may not be the application palette. In most cases
        there is no special palette for certain types of widgets, but one
        notable exception is the popup menu under Windows, if the user has
        defined a special background color for menus in the display settings.

        **See also** **setPalette** () and **QWidget::palette** ().
        """
        ...

    @typing.overload
    @staticmethod
    def setStyle(a0: "QStyle") -> None:
        """
        https://doc.qt.io/qt-6/qapplication.html#setStyle

        **[static] void QApplication::setStyle(QStyle * style )**

        Sets the application's GUI style to **style**. Ownership of the style
        object is transferred to **QApplication** , so **QApplication**  will
        delete the style object on application exit or when a new style is set
        and the old style is still the parent of the application object.

        Example usage:

        **QApplication** ::setStyle(**QStyleFactory** ::create("Fusion"));

        When switching application styles, the color palette is set back to the
        initial colors or the system defaults. This is necessary since certain
        styles have to adapt the color palette to be fully style-guide
        compliant.

        Setting the style before a palette has been set, i.e., before creating
        **QApplication** , will cause the application to use
        **QStyle::standardPalette** () for the palette.

        **Warning:** Qt style sheets are currently not supported for custom
        **QStyle**  subclasses. We plan to address this in some future release.

        **See also** **style** (), **QStyle** , **setPalette** (), and
        **desktopSettingsAware** ().
        """
        ...

    @typing.overload
    @staticmethod
    def setStyle(a0: str) -> "QStyle":
        """
        https://doc.qt.io/qt-6/qapplication.html#setStyle-1

        **[static] QStyle *QApplication::setStyle(const QString & style )**

        This is an overloaded function.

        Requests a **QStyle**  object for **style** from the **QStyleFactory** .

        The string must be one of the **QStyleFactory::keys** (), typically one
        of "windows", "windowsvista", "fusion", or "macos". Style names are case
        insensitive.

        Returns `nullptr` if an unknown **style** is passed, otherwise the
        **QStyle**  object returned is set as the application's GUI style.

        **Warning:** To ensure that the application's style is set correctly, it
        is best to call this function before the **QApplication**  constructor,
        if possible.
        """
        ...

    @staticmethod
    def style() -> "QStyle":
        """
        https://doc.qt.io/qt-6/qapplication.html#style

        **[static] QStyle *QApplication::style()**

        Returns the application's style object.

        **See also** **setStyle** () and **QStyle** .
        """
        ...

    @property
    def focusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qapplication.html#focusChanged

        **[signal] void QApplication::focusChanged(QWidget * old , QWidget * now
        )**

        This signal is emitted when the widget that has keyboard focus changed
        from **old** to **now** , i.e., because the user pressed the tab-key,
        clicked into a widget or changed the active window. Both **old** and
        **now** can be `nullptr`.

        The signal is emitted after both widget have been notified about the
        change through **QFocusEvent** .

        **See also** **QWidget::setFocus** (), **QWidget::clearFocus** (), and
        **Qt::FocusReason** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtGui import *


class QPointerEvent(QInputEvent):
    """
    https://doc.qt.io/qt-6/qpointerevent.html

    **Detailed Description**
    """

    def clone(self) -> "QPointerEvent":
        ...

    def setAccepted(self, accepted: bool) -> None:
        """
        https://doc.qt.io/qt-6/qpointerevent.html#setAccepted

        **[override virtual] void QPointerEvent::setAccepted(bool accepted )**
        """
        ...

    def allPointsAccepted(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpointerevent.html#allPointsAccepted

        **bool QPointerEvent::allPointsAccepted() const**

        Returns `true` if isPointAccepted() is `true` for every point in
        **points** (); otherwise `false`.
        """
        ...

    def isEndEvent(self) -> bool:
        ...

    def isUpdateEvent(self) -> bool:
        ...

    def isBeginEvent(self) -> bool:
        ...

    def pointById(self, id: int) -> "QEventPoint":
        """
        https://doc.qt.io/qt-6/qpointerevent.html#pointById

        **QEventPoint *QPointerEvent::pointById(int id )**

        Returns the point whose **id**  matches the given **id** , or `nullptr`
        if no such point is found.
        """
        ...

    def points(self) -> typing.List["QEventPoint"]:
        """
        https://doc.qt.io/qt-6/qpointerevent.html#points

        **const QList<QEventPoint> &QPointerEvent::points() const**

        Returns a list of points in this pointer event.
        """
        ...

    def point(self, i: int) -> "QEventPoint":
        """
        https://doc.qt.io/qt-6/qpointerevent.html#point

        **QEventPoint &QPointerEvent::point(qsizetype i )**

        Returns a **QEventPoint**  reference for the point at index **i**.
        """
        ...

    def pointCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qpointerevent.html#pointCount

        **qsizetype QPointerEvent::pointCount() const**

        Returns the number of points in this pointer event.
        """
        ...

    def pointerType(self) -> "QPointingDevice.PointerType":
        """
        https://doc.qt.io/qt-6/qpointerevent.html#pointerType

        **QPointingDevice::PointerType QPointerEvent::pointerType() const**

        Returns the type of point that generated the event.
        """
        ...

    def pointingDevice(self) -> "QPointingDevice":
        """
        https://doc.qt.io/qt-6/qpointerevent.html#pointingDevice

        **const QPointingDevice *QPointerEvent::pointingDevice() const**

        Returns the source device from which this event originates.

        This is the same as **QInputEvent::device** () but typecast for
        convenience.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtNetwork import *
import enum


class QHostInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhostinfo.html

    **Detailed Description**

    QHostInfo finds the IP address(es) associated with a host name, or the host
    name associated with an IP address. The class provides two static
    convenience functions: one that works asynchronously and emits a signal once
    the host is found, and one that blocks and returns a QHostInfo object.

    To look up a host's IP addresses asynchronously, call **lookupHost** (),
    which takes the host name or IP address, a receiver object, and a slot
    signature as arguments and returns an ID. You can abort the lookup by
    calling **abortHostLookup** () with the lookup ID.

    Example:

    // To find the IP address of qt-project.org
        **QHostInfo**
    ::lookupHost("qt-project.org",
                              this,
    SLOT(printResults(**QHostInfo** )));

        // To find the host name for
    4.2.2.1
        **QHostInfo** ::lookupHost("4.2.2.1",
    this, SLOT(printResults(**QHostInfo** )));

    The slot is invoked when the results are ready. The results are stored in a
    QHostInfo object. Call **addresses** () to get the list of IP addresses for
    the host, and **hostName** () to get the host name that was looked up.

    If the lookup failed, **error** () returns the type of error that occurred.
    **errorString** () gives a human-readable description of the lookup error.

    If you want a blocking lookup, use the **QHostInfo::fromName** () function:

    **QHostInfo**  info = **QHostInfo** ::fromName("qt-project.org");

    QHostInfo supports Internationalized Domain Names (IDNs) through the IDNA
    and Punycode standards.

    To retrieve the name of the local host, use the static
    **QHostInfo::localHostName** () function.

    QHostInfo uses the mechanisms provided by the operating system to perform
    the lookup. As per **RFC 6724**  there is no guarantee that all IP addresses
    registered for a domain or host will be returned.

    **Note:** Since Qt 4.6.1 QHostInfo is using multiple threads for DNS lookup
    instead of one dedicated DNS thread. This improves performance, but also
    changes the order of signal emissions when using **lookupHost** () compared
    to previous versions of Qt.

    **Note:** Since Qt 4.6.3 QHostInfo is using a small internal 60 second DNS
    cache for performance improvements.

    **See also** **QAbstractSocket** , **RFC 3492** , and **RFC 6724** .
    """

    class HostInfoError(enum.Enum):
        NoError: QHostInfo = ...
        HostNotFound: QHostInfo = ...
        UnknownError: QHostInfo = ...

    @typing.overload
    def __init__(self, id: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#QHostInfo

        **QHostInfo::QHostInfo(int id = -1)**

        Constructs an empty host info object with lookup ID **id**.

        **See also** **lookupId** ().
        """
        ...

    @typing.overload
    def __init__(self, d: "QHostInfo") -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#QHostInfo-1

        **QHostInfo::QHostInfo(const QHostInfo & other )**

        Constructs a copy of **other**.
        """
        ...

    def swap(self, other: "QHostInfo") -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#swap

        **[since 5.10] void QHostInfo::swap(QHostInfo & other )**

        Swaps host-info **other** with this host-info. This operation is very
        fast and never fails.

        This function was introduced in Qt 5.10.
        """
        ...

    @staticmethod
    def localDomainName() -> str:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#localDomainName

        **[static] QString QHostInfo::localDomainName()**

        Returns the DNS domain of this machine.

        **Note:** DNS domains are not related to domain names found in Windows
        networks.

        **See also** **hostName** ().
        """
        ...

    @staticmethod
    def localHostName() -> str:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#localHostName

        **[static] QString QHostInfo::localHostName()**

        Returns this machine's host name, if one is configured. Note that
        hostnames are not guaranteed to be globally unique, especially if they
        were configured automatically.

        This function does not guarantee the returned host name is a Fully
        Qualified Domain Name (FQDN). For that, use **fromName** () to resolve
        the returned name to an FQDN.

        This function returns the same as **QSysInfo::machineHostName** ().

        **See also** **hostName** () and **localDomainName** ().
        """
        ...

    @staticmethod
    def fromName(name: str) -> "QHostInfo":
        """
        https://doc.qt.io/qt-6/qhostinfo.html#fromName

        **[static] QHostInfo QHostInfo::fromName(const QString & name )**

        Looks up the IP address(es) for the given host **name**. The function
        blocks during the lookup which means that execution of the program is
        suspended until the results of the lookup are ready. Returns the result
        of the lookup in a **QHostInfo**  object.

        If you pass a literal IP address to **name** instead of a host name,
        **QHostInfo**  will search for the domain name for the IP (i.e.,
        **QHostInfo**  will perform a **reverse** lookup). On success, the
        returned **QHostInfo**  will contain both the resolved domain name and
        IP addresses for the host name.

        **See also** **lookupHost** ().
        """
        ...

    @staticmethod
    def abortHostLookup(lookupId: int) -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#abortHostLookup

        **[static] void QHostInfo::abortHostLookup(int id )**

        Aborts the host lookup with the ID **id** , as returned by
        **lookupHost** ().

        **See also** **lookupHost** () and **lookupId** ().
        """
        ...

    @staticmethod
    def lookupHost(name: str, slot: PYQT_SLOT) -> int:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#lookupHost

        **[static] int QHostInfo::lookupHost(const QString & name , QObject *
        receiver , const char * member )**

        Looks up the IP address(es) associated with host name **name** , and
        returns an ID for the lookup. When the result of the lookup is ready,
        the slot or signal **member** in **receiver** is called with a
        **QHostInfo**  argument. The **QHostInfo**  object can then be inspected
        to get the results of the lookup.

        The lookup is performed by a single function call, for example:

        **QHostInfo** ::lookupHost("www.kde.org",
        this, SLOT(lookedUp(**QHostInfo** )));

        The implementation of the slot prints basic information about the
        addresses returned by the lookup, or reports an error if it failed:

        void MyWidget::lookedUp(const **QHostInfo**  &host)
            {
                if
        (host.error() != **QHostInfo** ::NoError) {
                    **qDebug** () <<
        "Lookup failed:" << host.errorString();
                    return;
                }
        const auto addresses = host.addresses();
                for (const
        **QHostAddress**  &address : addresses)
                    **qDebug** () <<
        "Found address:" << address.toString();
            }

        If you pass a literal IP address to **name** instead of a host name,
        **QHostInfo**  will search for the domain name for the IP (i.e.,
        **QHostInfo**  will perform a **reverse** lookup). On success, the
        resulting **QHostInfo**  will contain both the resolved domain name and
        IP addresses for the host name. Example:

        **QHostInfo** ::lookupHost("4.2.2.1",
                                  this,
        SLOT(lookedUp(**QHostInfo** )));

        **Note:** There is no guarantee on the order the signals will be emitted
        if you start multiple requests with lookupHost().

        **See also** **abortHostLookup** (), **addresses** (), **error** (), and
        **fromName** ().
        """
        ...

    def lookupId(self) -> int:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#lookupId

        **int QHostInfo::lookupId() const**

        Returns the ID of this lookup.

        **See also** **setLookupId** (), **abortHostLookup** (), and
        **hostName** ().
        """
        ...

    def setLookupId(self, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#setLookupId

        **void QHostInfo::setLookupId(int id )**

        Sets the ID of this lookup to **id**.

        **See also** **lookupId** () and **lookupHost** ().
        """
        ...

    def setErrorString(self, errorString: str) -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#setErrorString

        **void QHostInfo::setErrorString(const QString & str )**

        Sets the human readable description of the error that occurred to
        **str** if the lookup failed.

        **See also** **errorString** () and **setError** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#errorString

        **QString QHostInfo::errorString() const**

        If the lookup failed, this function returns a human readable description
        of the error; otherwise "Unknown error" is returned.

        **See also** **setErrorString** () and **error** ().
        """
        ...

    def setError(self, error: "QHostInfo.HostInfoError") -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#setError

        **void QHostInfo::setError(QHostInfo::HostInfoError error )**

        Sets the error type of this **QHostInfo**  to **error**.

        **See also** **error** () and **errorString** ().
        """
        ...

    def error(self) -> "QHostInfo.HostInfoError":
        """
        https://doc.qt.io/qt-6/qhostinfo.html#error

        **QHostInfo::HostInfoError QHostInfo::error() const**

        Returns the type of error that occurred if the host name lookup failed;
        otherwise returns **NoError** .

        **See also** **setError** () and **errorString** ().
        """
        ...

    def setAddresses(
        self,
        addresses: typing.Iterable[
            typing.Union[QHostAddress, QHostAddress.SpecialAddress]
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#setAddresses

        **void QHostInfo::setAddresses(const QList<QHostAddress> & addresses )**

        Sets the list of addresses in this **QHostInfo**  to **addresses**.

        **See also** **addresses** ().
        """
        ...

    def addresses(self) -> typing.List[QHostAddress]:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#addresses

        **QList<QHostAddress> QHostInfo::addresses() const**

        Returns the list of IP addresses associated with **hostName** (). This
        list may be empty.

        Example:

        **QHostInfo**  info;
            ...
            if (!info.addresses().isEmpty()) {
        **QHostAddress**  address = info.addresses().first();
                // use the
        first IP address
            }

        **See also** **setAddresses** (), **hostName** (), and **error** ().
        """
        ...

    def setHostName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#setHostName

        **void QHostInfo::setHostName(const QString & hostName )**

        Sets the host name of this **QHostInfo**  to **hostName**.

        **See also** **hostName** ().
        """
        ...

    def hostName(self) -> str:
        """
        https://doc.qt.io/qt-6/qhostinfo.html#hostName

        **QString QHostInfo::hostName() const**

        Returns the name of the host whose IP addresses were looked up.

        **See also** **setHostName** () and **localHostName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtPositioning import *
import enum


class QGeoSatelliteInfo(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qgeosatelliteinfo.html

    **Detailed Description**

    **See also** **QGeoSatelliteInfoSource** .
    """

    class SatelliteSystem(enum.Enum):
        Undefined: QGeoSatelliteInfo = ...
        GPS: QGeoSatelliteInfo = ...
        GLONASS: QGeoSatelliteInfo = ...
        GALILEO: QGeoSatelliteInfo = ...
        BEIDOU: QGeoSatelliteInfo = ...
        QZSS: QGeoSatelliteInfo = ...
        Multiple: QGeoSatelliteInfo = ...
        CustomType: QGeoSatelliteInfo = ...

    class Attribute(enum.Enum):
        Elevation: QGeoSatelliteInfo = ...
        Azimuth: QGeoSatelliteInfo = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#QGeoSatelliteInfo

        **QGeoSatelliteInfo::QGeoSatelliteInfo()**

        Creates a satellite information object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoSatelliteInfo") -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#QGeoSatelliteInfo-1

        **QGeoSatelliteInfo::QGeoSatelliteInfo(const QGeoSatelliteInfo & other
        )**

        Creates a satellite information object with the values of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def swap(self, other: "QGeoSatelliteInfo") -> None:
        ...

    def hasAttribute(self, attribute: "QGeoSatelliteInfo.Attribute") -> bool:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#hasAttribute

        **bool QGeoSatelliteInfo::hasAttribute(QGeoSatelliteInfo::Attribute
        attribute ) const**

        Returns true if the specified **attribute** is present in this update.
        """
        ...

    def removeAttribute(self, attribute: "QGeoSatelliteInfo.Attribute") -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#removeAttribute

        **void QGeoSatelliteInfo::removeAttribute(QGeoSatelliteInfo::Attribute
        attribute )**

        Removes the specified **attribute** and its value.
        """
        ...

    def attribute(self, attribute: "QGeoSatelliteInfo.Attribute") -> float:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#attribute

        **qreal QGeoSatelliteInfo::attribute(QGeoSatelliteInfo::Attribute
        attribute ) const**

        Returns the value of the specified **attribute** as a qreal value.

        Returns -1 if the value has not been set.

        **See also** **hasAttribute** () and **setAttribute** ().
        """
        ...

    def setAttribute(
        self, attribute: "QGeoSatelliteInfo.Attribute", value: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#setAttribute

        **void QGeoSatelliteInfo::setAttribute(QGeoSatelliteInfo::Attribute
        attribute , qreal value )**

        Sets the value for **attribute** to **value**.

        **See also** **attribute** ().
        """
        ...

    def signalStrength(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#signalStrength

        **int QGeoSatelliteInfo::signalStrength() const**

        Returns the signal strength, or -1 if the value has not been set.

        **See also** **setSignalStrength** ().
        """
        ...

    def setSignalStrength(self, signalStrength: int) -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#setSignalStrength

        **void QGeoSatelliteInfo::setSignalStrength(int signalStrength )**

        Sets the signal strength to **signalStrength** , in decibels.

        **See also** **signalStrength** ().
        """
        ...

    def satelliteIdentifier(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#satelliteIdentifier

        **int QGeoSatelliteInfo::satelliteIdentifier() const**

        Returns the satellite identifier number.

        The satellite identifier number can be used to identify a satellite
        within the satellite system.

        The actual value may vary, depending on the platform and the selected
        backend.

        For example, if **nmea** plugin is used, the satellite identifier for
        GPS satellite system represents the PRN (Pseudo-random noise) number,
        and the satellite identifier for GLONASS satellite system represents the
        slot number.

        For NMEA-based backends the satellite identifier can be used to
        determine the satellite system type if it is not available from other
        sources. You can refer to **satellite IDs list**  to check the ID ranges
        for different satellite systems.

        **Note:** Depending on the platform and the selected backend, the
        satellite identifier ranges for different satellite systems may
        intersect. To uniquely identify a satellite, a combination of
        satelliteIndetifier() and **satelliteSystem** () must be used.

        **See also** **setSatelliteIdentifier** () and **satelliteSystem** ().
        """
        ...

    def setSatelliteIdentifier(self, satId: int) -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#setSatelliteIdentifier

        **void QGeoSatelliteInfo::setSatelliteIdentifier(int satId )**

        Sets the satellite identifier number to **satId**.

        The satellite identifier number can be used to identify a satellite
        within the satellite system.

        The actual value may vary, depending on the platform and the selected
        backend.

        For example, if **nmea** plugin is used, the satellite identifier for
        GPS satellite system represents the PRN (Pseudo-random noise) number,
        and the satellite identifier for GLONASS satellite system represents the
        slot number.

        **See also** **satelliteIdentifier** ().
        """
        ...

    def satelliteSystem(self) -> "QGeoSatelliteInfo.SatelliteSystem":
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#satelliteSystem

        **QGeoSatelliteInfo::SatelliteSystem
        QGeoSatelliteInfo::satelliteSystem() const**

        Returns the Satellite System (GPS, GLONASS, ...)

        **Note:** This value can be used together with **satelliteIdentifier**
        () to uniquely identify a satellite.

        **See also** **setSatelliteSystem** () and **satelliteIdentifier** ().
        """
        ...

    def setSatelliteSystem(self, system: "QGeoSatelliteInfo.SatelliteSystem") -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfo.html#setSatelliteSystem

        **void
        QGeoSatelliteInfo::setSatelliteSystem(QGeoSatelliteInfo::SatelliteSystem
        system )**

        Sets the Satellite System (GPS, GLONASS, ...) to **system**.

        **See also** **satelliteSystem** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QAudioOutput(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qaudiooutput.html

    **Detailed Description**

    This class represents an output channel that can be used together with
    **QMediaPlayer**  or **QMediaCaptureSession** . It enables the selection of
    the physical output device to be used, muting the channel, and changing the
    channel's volume.
    """

    @typing.overload
    def __init__(
        self, device: QAudioDevice, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...

    def setMuted(self, muted: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaudiooutput.html#muted-prop

        **muted : bool**

        This property holds the muted state of the current media.

        The value will be `true` if the output is muted; otherwise `false`.

        **Access functions:**

        bool **isMuted** () const
        void **setMuted** (bool **muted** )

        **Notifier signal:**

        void **mutedChanged** (bool **muted** )
        """
        ...

    def setVolume(self, volume: float) -> None:
        """
        https://doc.qt.io/qt-6/qaudiooutput.html#volume-prop

        **volume : float**

        This property holds the current volume.

        The volume is scaled linearly, ranging from `0` (silence) to `1` (full
        volume).

        **Note:** values outside this range will be clamped.

        By default the volume is `1`.

        UI volume controls should usually be scaled non-linearly. For example,
        using a logarithmic scale will produce linear changes in perceived
        loudness, which is what a user would normally expect from a volume
        control.

        **Access functions:**

        float **volume** () const
        void **setVolume** (float **volume** )

        **Notifier signal:**

        void **volumeChanged** (float **volume** )

        **See also** **QAudio::convertVolume** ().
        """
        ...

    def setDevice(self, device: QAudioDevice) -> None:
        """
        https://doc.qt.io/qt-6/qaudiooutput.html#device-prop

        **device : QAudioDevice**

        This property holds the audio device connected to this output.

        The device property represents the audio device this output is connected
        to. This property can be used to select an output device from the
        **QMediaDevices::audioOutputs** () list. You can select the system
        default audio output by setting this property to a default constructed
        **QAudioDevice**  object.

        **Access functions:**

        QAudioDevice **device** () const
        void **setDevice** (const
        QAudioDevice & **device** )

        **Notifier signal:**

        void **deviceChanged** ()
        """
        ...

    def isMuted(self) -> bool:
        ...

    def device(self) -> QAudioDevice:
        """
        https://doc.qt.io/qt-6/qaudiooutput.html#device-prop

        **device : QAudioDevice**

        This property holds the audio device connected to this output.

        The device property represents the audio device this output is connected
        to. This property can be used to select an output device from the
        **QMediaDevices::audioOutputs** () list. You can select the system
        default audio output by setting this property to a default constructed
        **QAudioDevice**  object.

        **Access functions:**

        QAudioDevice **device** () const
        void **setDevice** (const
        QAudioDevice & **device** )

        **Notifier signal:**

        void **deviceChanged** ()
        """
        ...

    def volume(self) -> float:
        """
        https://doc.qt.io/qt-6/qaudiooutput.html#volume-prop

        **volume : float**

        This property holds the current volume.

        The volume is scaled linearly, ranging from `0` (silence) to `1` (full
        volume).

        **Note:** values outside this range will be clamped.

        By default the volume is `1`.

        UI volume controls should usually be scaled non-linearly. For example,
        using a logarithmic scale will produce linear changes in perceived
        loudness, which is what a user would normally expect from a volume
        control.

        **Access functions:**

        float **volume** () const
        void **setVolume** (float **volume** )

        **Notifier signal:**

        void **volumeChanged** (float **volume** )

        **See also** **QAudio::convertVolume** ().
        """
        ...

    @property
    def deviceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def mutedChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def volumeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QDeadlineTimer(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdeadlinetimer.html

    **Detailed Description**

    The QDeadlineTimer class is usually used to calculate future deadlines and
    verify whether the deadline has expired. QDeadlineTimer can also be used for
    deadlines without expiration ("forever"). It forms a counterpart to
    **QElapsedTimer** , which calculates how much time has elapsed since
    **QElapsedTimer::start** () was called.

    QDeadlineTimer provides a more convenient API compared to
    **QElapsedTimer::hasExpired** ().

    The typical use-case for the class is to create a QDeadlineTimer before the
    operation in question is started, and then use **remainingTime** () or
    **hasExpired** () to determine whether to continue trying the operation.
    QDeadlineTimer objects can be passed to functions being called to execute
    this operation so they know how long to still operate.

    void executeOperation(int msecs)
            {
                **QDeadlineTimer**
    deadline(msecs);
                do {
                    if
    (readFromDevice(deadline.remainingTime()))
                        break;
    waitForReadyRead(deadline);
                } while (!deadline.hasExpired());
    }

    Many QDeadlineTimer functions deal with time out values, which all are
    measured in milliseconds. There are two special values, the same as many
    other Qt functions named `waitFor` or similar:

    * 0: no time left, expired
      * -1: infinite time left, timer never expires

    **Reference Clocks**

    QDeadlineTimer will use the same clock as **QElapsedTimer**  (see
    **QElapsedTimer::clockType** () and **QElapsedTimer::isMonotonic** ()).

    **Timer types**

    Like **QTimer** , QDeadlineTimer can select among different levels of
    coarseness on the timers. You can select precise timing by passing
    **Qt::PreciseTimer**  to the functions that set of change the timer, or you
    can select coarse timing by passing **Qt::CoarseTimer** .
    **Qt::VeryCoarseTimer**  is currently interpreted the same way as
    **Qt::CoarseTimer** .

    This feature is dependent on support from the operating system: if the OS
    does not support a coarse timer functionality, then QDeadlineTimer will
    behave like **Qt::PreciseTimer**  was passed.

    QDeadlineTimer defaults to **Qt::CoarseTimer**  because on operating systems
    that do support coarse timing, making timing calls to that clock source is
    often much more efficient. The level of coarseness depends on the operating
    system, but should be in the order of a couple of milliseconds.

    **`std::chrono` Compatibility**

    QDeadlineTimer is compatible with the `std::chrono` API from C++11 and can
    be constructed from or compared to both `std::chrono::duration` and
    `std::chrono::time_point` objects. In addition, it is fully compatible with
    the time literals from C++14, which allow one to write code as:

    using namespace std::chrono;
            using namespace std::chrono_literals;
    **QDeadlineTimer**  deadline(30s);
    device->waitForReadyRead(deadline);
            if
    (deadline.remainingTime<nanoseconds>() > 300ms)
                cleanup();

    As can be seen in the example above, QDeadlineTimer offers a templated
    version of **remainingTime** () and **deadline** () that can be used to
    return `std::chrono` objects.

    Note that comparing to `time_point` is not as efficient as comparing to
    `duration`, since QDeadlineTimer may need to convert from its own internal
    clock source to the clock source used by the `time_point` object. Also note
    that, due to this conversion, the deadlines will not be precise, so the
    following code is not expected to compare equally:

    using namespace std::chrono;
            using namespace std::chrono_literals;
    auto now = steady_clock::now();
            **QDeadlineTimer**  deadline(now +
    1s);
            Q_ASSERT(deadline == now + 1s);

    **See also** **QTime** , **QTimer** , **QDeadlineTimer** , and
    **Qt::TimerType** .
    """

    class ForeverConstant(enum.Enum):
        Forever: QDeadlineTimer = ...

    @typing.overload
    def __init__(self, type: Qt.TimerType = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#QDeadlineTimer

        **QDeadlineTimer::QDeadlineTimer(Qt::TimerType timerType =
        Qt::CoarseTimer)**

        Constructs an expired QDeadlineTimer object. For this object,
        **remainingTime** () will return 0.

        The timer type **timerType** may be ignored, since the timer is already
        expired. Similarly, for optimization purposes, this function will not
        attempt to obtain the current time and will use a value known to be in
        the past. Therefore, **deadline** () may return an unexpected value and
        this object cannot be used in calculation of how long it is overdue. If
        that functionality is required, use **QDeadlineTimer::current** ().

        **See also** **hasExpired** (), **remainingTime** (), **Qt::TimerType**
        , and **current** ().
        """
        ...

    @typing.overload
    def __init__(
        self, a0: "QDeadlineTimer.ForeverConstant", type: Qt.TimerType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#QDeadlineTimer-1

        **QDeadlineTimer::QDeadlineTimer(QDeadlineTimer::ForeverConstant,
        Qt::TimerType timerType = Qt::CoarseTimer)**

        QDeadlineTimer objects created with **ForeverConstant**  never expire.
        For such objects, **remainingTime** () will return -1, **deadline** ()
        will return the maximum value, and **isForever** () will return true.

        The timer type **timerType** may be ignored, since the timer will never
        expire.

        **See also** **ForeverConstant** , **hasExpired** (), **isForever** (),
        **remainingTime** (), and **timerType** ().
        """
        ...

    @typing.overload
    def __init__(self, msecs: int, type: Qt.TimerType = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#QDeadlineTimer-2

        **QDeadlineTimer::QDeadlineTimer(qint64 msecs , Qt::TimerType type =
        Qt::CoarseTimer)**

        Constructs a QDeadlineTimer object with an expiry time of **msecs**
        msecs from the moment of the creation of this object, if msecs is
        positive. If **msecs** is zero, this QDeadlineTimer will be marked as
        expired, causing **remainingTime** () to return zero and **deadline** ()
        to return an indeterminate time point in the past. If **msecs** is -1,
        the timer will be set to never expire, causing **remainingTime** () to
        return -1 and **deadline** () to return the maximum value.

        The QDeadlineTimer object will be constructed with the specified timer
        **type**.

        For optimization purposes, if **msecs** is zero, this function may skip
        obtaining the current time and may instead use a value known to be in
        the past. If that happens, **deadline** () may return an unexpected
        value and this object cannot be used in calculation of how long it is
        overdue. If that functionality is required, use
        **QDeadlineTimer::current** () and add time to it.

        **See also** **hasExpired** (), **isForever** (), **remainingTime** (),
        and **setRemainingTime** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDeadlineTimer") -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#QDeadlineTimer-3

        **template <typename Clock, typename Duration>
        QDeadlineTimer::QDeadlineTimer(std::chrono::time_point<Clock, Duration>
        deadline , Qt::TimerType type = Qt::CoarseTimer)**

        Constructs a QDeadlineTimer object with a deadline at **deadline** time
        point, converting from the clock source `Clock` to Qt's internal clock
        source (see **QElapsedTimer::clockType** ()).

        If **deadline** is in the past, this QDeadlineTimer object is set to
        expired, whereas if **deadline** is equal to `Duration::max()`, then
        this object is set to never expire.

        The QDeadlineTimer object will be constructed with the specified timer
        **type**.

        **See also** **hasExpired** (), **isForever** (), **remainingTime** (),
        and **setDeadline** ().
        """
        ...

    @staticmethod
    def current(type: Qt.TimerType = ...) -> "QDeadlineTimer":
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#current

        **[static] QDeadlineTimer QDeadlineTimer::current(Qt::TimerType
        timerType = Qt::CoarseTimer)**

        Returns a **QDeadlineTimer**  that is expired but is guaranteed to
        contain the current time. Objects created by this function can
        participate in the calculation of how long a timer is overdue, using the
        **deadline** () function.

        The **QDeadlineTimer**  object will be constructed with the specified
        **timerType**.
        """
        ...

    @staticmethod
    def addNSecs(dt: "QDeadlineTimer", nsecs: int) -> "QDeadlineTimer":
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#addNSecs

        **[static] QDeadlineTimer QDeadlineTimer::addNSecs(QDeadlineTimer dt ,
        qint64 nsecs )**

        Returns a **QDeadlineTimer**  object whose deadline is extended from
        **dt** 's deadline by **nsecs** nanoseconds. If **dt** was set to never
        expire, this function returns a **QDeadlineTimer**  that will not expire
        either.

        **Note:** if **dt** was created as expired, its deadline is
        indeterminate and adding an amount of time may or may not cause it to
        become unexpired.
        """
        ...

    def setPreciseDeadline(
        self, secs: int, nsecs: int = ..., type: Qt.TimerType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#setPreciseDeadline

        **void QDeadlineTimer::setPreciseDeadline(qint64 secs , qint64 nsecs =
        0, Qt::TimerType timerType = Qt::CoarseTimer)**

        Sets the deadline for this **QDeadlineTimer**  object to be **secs**
        seconds and **nsecs** nanoseconds since the reference clock epoch (the
        same as **QElapsedTimer::msecsSinceReference** ()), and the timer type
        to **timerType**. If the value is in the past, this **QDeadlineTimer**
        will be marked as expired.

        If **secs** or **nsecs** is `std::numeric_limits<qint64>::max()`, this
        **QDeadlineTimer**  will be set to never expire. If **nsecs** is more
        than 1 billion nanoseconds (1 second), then **secs** will be adjusted
        accordingly.

        **See also** **setDeadline** (), **deadline** (), **deadlineNSecs** (),
        and **setRemainingTime** ().
        """
        ...

    def setDeadline(self, msecs: int, type: Qt.TimerType = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#setDeadline

        **void QDeadlineTimer::setDeadline(qint64 msecs , Qt::TimerType
        timerType = Qt::CoarseTimer)**

        Sets the deadline for this **QDeadlineTimer**  object to be the
        **msecs** absolute time point, counted in milliseconds since the
        reference clock (the same as **QElapsedTimer::msecsSinceReference** ()),
        and the timer type to **timerType**. If the value is in the past, this
        **QDeadlineTimer**  will be marked as expired.

        If **msecs** is `std::numeric_limits<qint64>::max()` or the deadline is
        beyond a representable point in the future, this **QDeadlineTimer**
        will be set to never expire.

        **See also** **setPreciseDeadline** (), **deadline** (),
        **deadlineNSecs** (), and **setRemainingTime** ().
        """
        ...

    def deadlineNSecs(self) -> int:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#deadlineNSecs

        **qint64 QDeadlineTimer::deadlineNSecs() const**

        Returns the absolute time point for the deadline stored in
        **QDeadlineTimer**  object, calculated in nanoseconds relative to the
        reference clock, the same as **QElapsedTimer::msecsSinceReference** ().
        The value will be in the past if this **QDeadlineTimer**  has expired.

        If this **QDeadlineTimer**  never expires or the number of nanoseconds
        until the deadline can't be accommodated in the return type, this
        function returns `std::numeric_limits<qint64>::max()`.

        This function can be used to calculate the amount of time a timer is
        overdue, by subtracting **QDeadlineTimer::current** (), as in the
        following example:

        **qint64**  realTimeLeft = deadline.deadlineNSecs();
                if
        (realTimeLeft != std::numeric_limits<**qint64** >::max())
        realTimeLeft -= **QDeadlineTimer** ::current().deadlineNSecs();

        **Note:** Timers that were created as expired have an indetermine time
        point in the past as their deadline, so the above calculation may not
        work.

        **See also** **remainingTime** () and deadlineNSecs().
        """
        ...

    def deadline(self) -> int:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#deadline

        **qint64 QDeadlineTimer::deadline() const**

        Returns the absolute time point for the deadline stored in
        **QDeadlineTimer**  object, calculated in milliseconds relative to the
        reference clock, the same as **QElapsedTimer::msecsSinceReference** ().
        The value will be in the past if this **QDeadlineTimer**  has expired.

        If this **QDeadlineTimer**  never expires, this function returns
        `std::numeric_limits<qint64>::max()`.

        This function can be used to calculate the amount of time a timer is
        overdue, by subtracting **QDeadlineTimer::current** () or
        **QElapsedTimer::msecsSinceReference** (), as in the following example:

        **qint64**  realTimeLeft = deadline.deadline();
                if (realTimeLeft
        != (std::numeric_limits<**qint64** >::max)()) {
                    realTimeLeft
        -= **QDeadlineTimer** ::current().deadline();
                    // or:
        //QElapsedTimer timer;
                    //timer.start();
        //realTimeLeft -= timer.msecsSinceReference();
                }

        **Note:** Timers that were created as expired have an indetermine time
        point in the past as their deadline, so the above calculation may not
        work.

        **See also** **remainingTime** (), **deadlineNSecs** (), and
        **setDeadline** ().
        """
        ...

    def setPreciseRemainingTime(
        self, secs: int, nsecs: int = ..., type: Qt.TimerType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#setPreciseRemainingTime

        **void QDeadlineTimer::setPreciseRemainingTime(qint64 secs , qint64
        nsecs = 0, Qt::TimerType timerType = Qt::CoarseTimer)**

        Sets the remaining time for this **QDeadlineTimer**  object to **secs**
        seconds plus **nsecs** nanoseconds from now, if **secs** has a positive
        value. If **secs** is -1, this **QDeadlineTimer**  will be set it to
        never expire. If both parameters are zero, this **QDeadlineTimer**  will
        be marked as expired.

        The timer type for this **QDeadlineTimer**  object will be set to the
        specified **timerType**.

        **See also** **setRemainingTime** (), **hasExpired** (), **isForever**
        (), and **remainingTime** ().
        """
        ...

    def setRemainingTime(self, msecs: int, type: Qt.TimerType = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#setRemainingTime

        **void QDeadlineTimer::setRemainingTime(qint64 msecs , Qt::TimerType
        timerType = Qt::CoarseTimer)**

        Sets the remaining time for this **QDeadlineTimer**  object to **msecs**
        milliseconds from now, if **msecs** has a positive value. If **msecs**
        is zero, this **QDeadlineTimer**  object will be marked as expired,
        whereas a value of -1 will set it to never expire.

        The timer type for this **QDeadlineTimer**  object will be set to the
        specified **timerType**.

        **See also** **setPreciseRemainingTime** (), **hasExpired** (),
        **isForever** (), and **remainingTime** ().
        """
        ...

    def remainingTimeNSecs(self) -> int:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#remainingTimeNSecs

        **qint64 QDeadlineTimer::remainingTimeNSecs() const**

        Returns the remaining time in this **QDeadlineTimer**  object in
        nanoseconds. If the timer has already expired, this function will return
        zero and it is not possible to obtain the amount of time overdue with
        this function. If the timer was set to never expire, this function
        returns -1.

        **See also** **remainingTime** (), **isForever** (), and **hasExpired**
        ().
        """
        ...

    def remainingTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#remainingTime

        **qint64 QDeadlineTimer::remainingTime() const**

        Returns the remaining time in this **QDeadlineTimer**  object in
        milliseconds. If the timer has already expired, this function will
        return zero and it is not possible to obtain the amount of time overdue
        with this function (to do that, see **deadline** ()). If the timer was
        set to never expire, this function returns -1.

        This function is suitable for use in Qt APIs that take a millisecond
        timeout, such as the many **QIODevice**  `waitFor` functions or the
        timed lock functions in **QMutex** , **QWaitCondition** , **QSemaphore**
        , or **QReadWriteLock** . For example:

        mutex.tryLock(deadline.remainingTime());

        **See also** **setRemainingTime** (), **remainingTimeNSecs** (),
        **isForever** (), and **hasExpired** ().
        """
        ...

    def setTimerType(self, type: Qt.TimerType) -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#setTimerType

        **void QDeadlineTimer::setTimerType(Qt::TimerType timerType )**

        Changes the timer type for this object to **timerType**.

        The behavior for each possible value of **timerType** is operating-
        system dependent. **Qt::PreciseTimer**  will use the most precise timer
        that Qt can find, with resolution of 1 millisecond or better, whereas
        **QDeadlineTimer**  will try to use a more coarse timer for
        **Qt::CoarseTimer**  and **Qt::VeryCoarseTimer** .

        **See also** **timerType** () and **Qt::TimerType** .
        """
        ...

    def timerType(self) -> Qt.TimerType:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#timerType

        **Qt::TimerType QDeadlineTimer::timerType() const**

        Returns the timer type is active for this object.

        **See also** **setTimerType** ().
        """
        ...

    def hasExpired(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#hasExpired

        **bool QDeadlineTimer::hasExpired() const**

        Returns true if this **QDeadlineTimer**  object has expired, false if
        there remains time left. For objects that have expired,
        **remainingTime** () will return zero and **deadline** () will return a
        time point in the past.

        **QDeadlineTimer**  objects created with the **ForeverConstant**  never
        expire and this function always returns false for them.

        **See also** **isForever** () and **remainingTime** ().
        """
        ...

    def isForever(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#isForever

        **bool QDeadlineTimer::isForever() const**

        Returns true if this **QDeadlineTimer**  object never expires, false
        otherwise. For timers that never expire, **remainingTime** () always
        returns -1 and **deadline** () returns the maximum value.

        **See also** **ForeverConstant** , **hasExpired** (), and
        **remainingTime** ().
        """
        ...

    def swap(self, other: "QDeadlineTimer") -> None:
        """
        https://doc.qt.io/qt-6/qdeadlinetimer.html#swap

        **void QDeadlineTimer::swap(QDeadlineTimer & other )**

        Swaps this deadline timer with the **other** deadline timer.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtQml
from PyQt6 import QtCore


class QQuick3DObject(QtCore.QObject, QtQml.QQmlParserStatus):
    """
    https://doc.qt.io/qt-6/qquick3dobject.html

    **Detailed Description**

    **Object3D**  is the base class for all Qt Quick 3D scene objects. Currently
    the types available in C++ are:

    * **QQuick3DGeometry**
      * **QQuick3DTextureData**

    Both of these types are resource objects which directly inherit
    QQuick3DObject.

    It should not be necessary to use QQuick3DObject directly anywhere currently
    because it is just an interface for supporting spatial items and resources
    in a 3D scene, as well as exposing similar functionality as **QQuickItem**
    for 3D scene content.
    """

    def __init__(self, parent: typing.Optional["QQuick3DObject"] = ...) -> None:
        ...

    def componentComplete(self) -> None:
        ...

    def classBegin(self) -> None:
        ...

    def setParentItem(self, parentItem: "QQuick3DObject") -> None:
        ...

    def parentItem(self) -> "QQuick3DObject":
        ...

    def setState(self, state: str) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dobject.html#state-prop

        **state : QString**

        This property holds the name of the current state of the object.

        If the item is in its default state, that is, no explicit state has been
        set, then this property holds an empty string. Likewise, you can return
        an item to its default state by setting this property to an empty
        string.

        **Access functions:**

        QString **state** () const
        void **setState** (const QString &
        **state** )

        **Notifier signal:**

        void **stateChanged** ()

        **See also** **Qt Quick States** .
        """
        ...

    def state(self) -> str:
        """
        https://doc.qt.io/qt-6/qquick3dobject.html#state-prop

        **state : QString**

        This property holds the name of the current state of the object.

        If the item is in its default state, that is, no explicit state has been
        set, then this property holds an empty string. Likewise, you can return
        an item to its default state by setting this property to an empty
        string.

        **Access functions:**

        QString **state** () const
        void **setState** (const QString &
        **state** )

        **Notifier signal:**

        void **stateChanged** ()

        **See also** **Qt Quick States** .
        """
        ...

    @property
    def parentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip


class QCollatorSortKey(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcollatorsortkey.html

    **Detailed Description**

    The QCollatorSortKey class is always created by **QCollator::sortKey** ()
    and is used for fast strings collation, for example when collating many
    strings.

    **See also** **QCollator** , **QCollator::sortKey** (), and **compare** ().
    """

    def __init__(self, other: "QCollatorSortKey") -> None:
        """
        https://doc.qt.io/qt-6/qcollatorsortkey.html#QCollatorSortKey

        **QCollatorSortKey::QCollatorSortKey(const QCollatorSortKey & other )**

        Constructs a copy of the **other** collator key.
        """
        ...

    def compare(self, key: "QCollatorSortKey") -> int:
        """
        https://doc.qt.io/qt-6/qcollatorsortkey.html#compare

        **int QCollatorSortKey::compare(const QCollatorSortKey & otherKey )
        const**

        Compares this key to **otherKey** , which must have been created by the
        same **QCollator** 's sortKey() as this key. The comparison is performed
        in accordance with that **QCollator** 's sort order.

        Returns a negative value if this key sorts before **otherKey** , 0 if
        the two keys are equal or a positive value if this key sorts after
        **otherKey**.

        **See also** **operator<** ().
        """
        ...

    def swap(self, other: "QCollatorSortKey") -> None:
        """
        https://doc.qt.io/qt-6/qcollatorsortkey.html#swap

        **void QCollatorSortKey::swap(QCollatorSortKey & other )**

        Swaps this collator key with **other**.
        """
        ...
